@@ -10,6 +10,8 @@
  * Get the variables sent or posted to this script and a core script
  */
 require_once 'libraries/common.inc.php';
+require_once 'libraries/sql.lib.php';
+require_once 'libraries/bookmark.lib.php';
 //require_once 'libraries/display_import_functions.lib.php';
 
 if (isset($_REQUEST['show_as_php'])) {
@@ -69,13 +71,20 @@ if (! empty($sql_query)) {
     }
 
     // refresh navigation panel only
-    if (preg_match('/^(CREATE|ALTER)\s+(VIEW|TABLE|DATABASE|SCHEMA)\s+/i', $sql_query)) {
+    if (preg_match(
+        '/^(CREATE|ALTER)\s+(VIEW|TABLE|DATABASE|SCHEMA)\s+/i',
+        $sql_query
+    )) {
         $ajax_reload['reload'] = true;
     }
 
     // do a dynamic reload if table is RENAMED
     // (by sending the instruction to the AJAX response handler)
-    if (preg_match('/^RENAME\s+TABLE\s+(.*?)\s+TO\s+(.*?)($|;|\s)/i', $sql_query, $rename_table_names)) {
+    if (preg_match(
+        '/^RENAME\s+TABLE\s+(.*?)\s+TO\s+(.*?)($|;|\s)/i',
+        $sql_query,
+        $rename_table_names
+    )) {
         $ajax_reload['table_name'] = PMA_Util::unQuote($rename_table_names[2]);
         $ajax_reload['reload'] = true;
     }
@@ -123,7 +132,7 @@ if ($_POST == array() && $_GET == array()) {
  */
 
 if (! in_array(
-    $format, 
+    $format,
     array(
         'csv',
         'ldi',
@@ -142,7 +151,7 @@ if (! in_array(
 
 $post_patterns = array(
     '/^force_file_/',
-    '/^'. $format . '_/'
+    '/^' . $format . '_/'
 );
 foreach (array_keys($_POST) as $post_key) {
     foreach ($post_patterns as $one_post_pattern) {
@@ -163,15 +172,15 @@ require_once 'libraries/import.lib.php';
 
 // Create error and goto url
 if ($import_type == 'table') {
-    $err_url = 'tbl_import.php?' . PMA_generate_common_url($db, $table);
+    $err_url = 'tbl_import.php?' . PMA_URL_getCommon($db, $table);
     $_SESSION['Import_message']['go_back_url'] = $err_url;
     $goto = 'tbl_import.php';
 } elseif ($import_type == 'database') {
-    $err_url = 'db_import.php?' . PMA_generate_common_url($db);
+    $err_url = 'db_import.php?' . PMA_URL_getCommon($db);
     $_SESSION['Import_message']['go_back_url'] = $err_url;
     $goto = 'db_import.php';
 } elseif ($import_type == 'server') {
-    $err_url = 'server_import.php?' . PMA_generate_common_url();
+    $err_url = 'server_import.php?' . PMA_URL_getCommon();
     $_SESSION['Import_message']['go_back_url'] = $err_url;
     $goto = 'server_import.php';
 } else {
@@ -185,11 +194,11 @@ if ($import_type == 'table') {
         }
     }
     if (strlen($table) && strlen($db)) {
-        $common = PMA_generate_common_url($db, $table);
+        $common = PMA_URL_getCommon($db, $table);
     } elseif (strlen($db)) {
-        $common = PMA_generate_common_url($db);
+        $common = PMA_URL_getCommon($db);
     } else {
-        $common = PMA_generate_common_url();
+        $common = PMA_URL_getCommon();
     }
     $err_url  = $goto . '?' . $common
         . (preg_match('@^tbl_[a-z]*\.php$@', $goto)
@@ -197,10 +206,15 @@ if ($import_type == 'table') {
             : '');
     $_SESSION['Import_message']['go_back_url'] = $err_url;
 }
+// Avoid setting selflink to 'import.php'
+// problem similar to bug 4276
+if (basename($_SERVER['SCRIPT_NAME']) === 'import.php') {
+    $_SERVER['SCRIPT_NAME'] = $goto;
+}
 
 
 if (strlen($db)) {
-    PMA_DBI_select_db($db);
+    $GLOBALS['dbi']->selectDb($db);
 }
 
 @set_time_limit($cfg['ExecTimeLimit']);
@@ -253,12 +267,19 @@ if (! empty($id_bookmark)) {
         }
 
         // refresh navigation and main panels
-        if (preg_match('/^(DROP)\s+(VIEW|TABLE|DATABASE|SCHEMA)\s+/i', $import_text)) {
+        if (preg_match(
+            '/^(DROP)\s+(VIEW|TABLE|DATABASE|SCHEMA)\s+/i',
+            $import_text
+        )) {
             $GLOBALS['reload'] = true;
         }
 
         // refresh navigation panel only
-        if (preg_match('/^(CREATE|ALTER)\s+(VIEW|TABLE|DATABASE|SCHEMA)\s+/i', $import_text)) {
+        if (preg_match(
+            '/^(CREATE|ALTER)\s+(VIEW|TABLE|DATABASE|SCHEMA)\s+/i',
+            $import_text
+        )
+        ) {
             $ajax_reload['reload'] = true;
         }
         break;
@@ -278,7 +299,7 @@ if (! empty($id_bookmark)) {
         break;
     case 2: // bookmarked query that have to be deleted
         $import_text = PMA_Bookmark_get($db, $id_bookmark);
-        PMA_Bookmark_delete($db, $id_bookmark);
+        PMA_Bookmark_delete($id_bookmark);
         if ($GLOBALS['is_ajax_request'] == true) {
             $message = PMA_Message::success(__('The bookmark has been deleted.'));
             $response = PMA_Response::getInstance();
@@ -349,23 +370,36 @@ if ($import_file != 'none' && ! $error) {
     $open_basedir = @ini_get('open_basedir');
 
     // If we are on a server with open_basedir, we must move the file
-    // before opening it. The doc explains how to create the "./tmp"
-    // directory
+    // before opening it.
 
     if (! empty($open_basedir)) {
-
-        $tmp_subdir = (PMA_IS_WINDOWS ? '.\\tmp\\' : 'tmp/');
-
+        $tmp_subdir = ini_get('upload_tmp_dir');
+        if (empty($tmp_subdir)) {
+            $tmp_subdir = sys_get_temp_dir();
+        }
+        $tmp_subdir = rtrim($tmp_subdir, DIRECTORY_SEPARATOR);
         if (is_writable($tmp_subdir)) {
-
-
-            $import_file_new = $tmp_subdir . basename($import_file) . uniqid();
+            $import_file_new = $tmp_subdir . DIRECTORY_SEPARATOR
+                . basename($import_file) . uniqid();
             if (move_uploaded_file($import_file, $import_file_new)) {
                 $import_file = $import_file_new;
                 $file_to_unlink = $import_file_new;
             }
 
             $size = filesize($import_file);
+        } else {
+
+            // If the php.ini is misconfigured (eg. there is no /tmp access defined
+            // with open_basedir), $tmp_subdir won't be writable and the user gets
+            // a 'File could not be read!' error (at PMA_detectCompression), which
+            // is not too meaningful. Show a meaningful error message to the user
+            // instead.
+
+            $message = PMA_Message::error(
+                __('Uploaded file cannot be moved, because the server has open_basedir enabled without access to the %s directory (for temporary files).')
+            );
+            $message->addParam($tmp_subdir);
+            PMA_stopImport($message);
         }
     }
 
@@ -375,8 +409,8 @@ if ($import_file != 'none' && ! $error) {
      */
     $compression = PMA_detectCompression($import_file);
     if ($compression === false) {
-        $message = PMA_Message::error(__('File could not be read'));
-        $error = true;
+        $message = PMA_Message::error(__('File could not be read!'));
+        PMA_stopImport($message);
     } else {
         switch ($compression) {
         case 'application/bzip2':
@@ -387,7 +421,7 @@ if ($import_file != 'none' && ! $error) {
                     __('You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.')
                 );
                 $message->addParam($compression);
-                $error = true;
+                PMA_stopImport($message);
             }
             break;
         case 'application/gzip':
@@ -398,7 +432,7 @@ if ($import_file != 'none' && ! $error) {
                     __('You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.')
                 );
                 $message->addParam($compression);
-                $error = true;
+                PMA_stopImport($message);
             }
             break;
         case 'application/zip':
@@ -407,19 +441,19 @@ if ($import_file != 'none' && ! $error) {
                  * Load interface for zip extension.
                  */
                 include_once 'libraries/zip_extension.lib.php';
-                $result = PMA_getZipContents($import_file);
-                if (! empty($result['error'])) {
-                    $message = PMA_Message::rawError($result['error']);
-                    $error = true;
+                $zipResult = PMA_getZipContents($import_file);
+                if (! empty($zipResult['error'])) {
+                    $message = PMA_Message::rawError($zipResult['error']);
+                    PMA_stopImport($message);
                 } else {
-                    $import_text = $result['data'];
+                    $import_text = $zipResult['data'];
                 }
             } else {
                 $message = PMA_Message::error(
                     __('You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.')
                 );
                 $message->addParam($compression);
-                $error = true;
+                PMA_stopImport($message);
             }
             break;
         case 'none':
@@ -430,21 +464,21 @@ if ($import_file != 'none' && ! $error) {
                 __('You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.')
             );
             $message->addParam($compression);
-            $error = true;
+            PMA_stopImport($message);
             break;
         }
     }
     // use isset() because zip compression type does not use a handle
     if (! $error && isset($import_handle) && $import_handle === false) {
-        $message = PMA_Message::error(__('File could not be read'));
-        $error = true;
+        $message = PMA_Message::error(__('File could not be read!'));
+        PMA_stopImport($message);
     }
 } elseif (! $error) {
     if (! isset($import_text) || empty($import_text)) {
         $message = PMA_Message::error(
             __('No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See [doc@faq1-16]FAQ 1.16[/doc].')
         );
-        $error = true;
+        PMA_stopImport($message);
     }
 }
 
@@ -460,12 +494,12 @@ if ($GLOBALS['PMA_recoding_engine'] != PMA_CHARSET_NONE && isset($charset_of_fil
     if (PMA_DRIZZLE) {
         // Drizzle doesn't support other character sets,
         // so we can't fallback to SET NAMES - throw an error
-        $error = true;
         $message = PMA_Message::error(
-            __('Cannot convert file\'s character set without character set conversion library')
+            __('Cannot convert file\'s character set without character set conversion library!')
         );
+        PMA_stopImport($message);
     } else {
-        PMA_DBI_query('SET NAMES \'' . $charset_of_file . '\'');
+        $GLOBALS['dbi']->query('SET NAMES \'' . $charset_of_file . '\'');
         // We can not show query in this case, it is in different charset
         $sql_query_disabled = true;
         $reset_charset = true;
@@ -477,7 +511,7 @@ if (! $error && isset($skip)) {
     $original_skip = $skip;
     while ($skip > 0) {
         PMA_importGetNextChunk($skip < $read_limit ? $skip : $read_limit);
-        // Disable read progresivity, otherwise we eat all memory!
+        // Disable read progressivity, otherwise we eat all memory!
         $read_multiply = 1;
         $skip -= $read_limit;
     }
@@ -498,17 +532,17 @@ if (! $error) {
         $import_type
     );
     if ($import_plugin == null) {
-        $error = true;
         $message = PMA_Message::error(
             __('Could not load import plugins, please check your installation!')
         );
+        PMA_stopImport($message);
     } else {
         // Do the real import
         $import_plugin->doImport($sql_data);
     }
 }
 
-if (! $error && false !== $import_handle && null !== $import_handle) {
+if (false !== $import_handle && null !== $import_handle) {
     fclose($import_handle);
 }
 
@@ -519,8 +553,8 @@ if ($file_to_unlink != '') {
 
 // Reset charset back, if we did some changes
 if ($reset_charset) {
-    PMA_DBI_query('SET CHARACTER SET utf8');
-    PMA_DBI_query(
+    $GLOBALS['dbi']->query('SET CHARACTER SET utf8');
+    $GLOBALS['dbi']->query(
         'SET SESSION collation_connection =\'' . $collation_connection . '\''
     );
 }
@@ -534,35 +568,29 @@ if (! empty($id_bookmark) && $action_bookmark == 2) {
     $message = PMA_Message::notice(__('Showing bookmark'));
 } elseif ($bookmark_created) {
     $special_message = '[br]'  . sprintf(
-        __('Bookmark %s created'),
+        __('Bookmark %s has been created.'),
         htmlspecialchars($bkm_label)
     );
 } elseif ($finished && ! $error) {
     if ($import_type == 'query') {
         $message = PMA_Message::success();
     } else {
-        if ($import_notice) {
-            $message = PMA_Message::success(
-                '<em>' . __('Import has been successfully finished, %d queries executed.') . '</em>'
-            );
-            $message->addParam($executed_queries);
+        $message = PMA_Message::success(
+            '<em>'
+            . __('Import has been successfully finished, %d queries executed.')
+            . '</em>'
+        );
+        $message->addParam($executed_queries);
 
+        if ($import_notice) {
             $message->addString($import_notice);
-            if (isset($local_import_file)) {
-                $message->addString('(' . $local_import_file . ')');
-            } else {
-                $message->addString('(' . $_FILES['import_file']['name'] . ')');
-            }
+        }
+        if (isset($local_import_file)) {
+            $message->addString('(' . htmlspecialchars($local_import_file) . ')');
         } else {
-            $message = PMA_Message::success(
-                __('Import has been successfully finished, %d queries executed.')
+            $message->addString(
+                '(' . htmlspecialchars($_FILES['import_file']['name']) . ')'
             );
-            $message->addParam($executed_queries);
-            if (isset($local_import_file)) {
-                $message->addString('(' . $local_import_file . ')');
-            } else {
-                $message->addString('(' . $_FILES['import_file']['name'] . ')');
-            }
         }
     }
 }
@@ -589,34 +617,49 @@ if (isset($message)) {
 // (but if the query is too large, in case of an imported file, the parser
 //  can choke on it so avoid parsing)
 if (strlen($sql_query) <= $GLOBALS['cfg']['MaxCharactersInDisplayedSQL']) {
-    include_once 'libraries/parse_analyze.lib.php';
+    include_once 'libraries/parse_analyze.inc.php';
 }
 
 // There was an error?
 if (isset($my_die)) {
-    foreach ($my_die AS $key => $die) {
+    foreach ($my_die as $key => $die) {
         PMA_Util::mysqlDie(
-            $die['error'], $die['sql'], '', $err_url, $error
+            $die['error'], $die['sql'], false, $err_url, $error
         );
     }
 }
 
-// we want to see the results of the last query that returned at least a row
-if (! empty($last_query_with_results)) {
-    // but we want to show intermediate results too
-    $disp_query = $sql_query;
-    $disp_message = __('Your SQL query has been executed successfully');
-    $sql_query = $last_query_with_results;
-    $go_sql = true;
-}
-
 if ($go_sql) {
-    include 'sql.php';
+    // parse sql query
+    include_once 'libraries/parse_analyze.inc.php';
+
+    if (isset($ajax_reload) && $ajax_reload['reload'] === true) {
+        $response = PMA_Response::getInstance();
+        $response->addJSON('ajax_reload', $ajax_reload);
+    }
+    PMA_executeQueryAndSendQueryResponse(
+        $analyzed_sql_results, false, $db, $table, null, $import_text, null,
+        $analyzed_sql_results['is_affected'], null,
+        null, null, null, $goto, $pmaThemeImage, null, null, null, $sql_query,
+        null, null
+    );
 } else if ($result) {
+    // Save a Bookmark with more than one queries (if Bookmark label given).
+    if (! empty($_POST['bkm_label']) && ! empty($import_text)) {
+        PMA_storeTheQueryAsBookmark(
+            $db, $GLOBALS['cfg']['Bookmark']['user'],
+            $import_text, $_POST['bkm_label'],
+            isset($_POST['bkm_replace']) ? $_POST['bkm_replace'] : null
+        );
+    }
+
     $response = PMA_Response::getInstance();
     $response->isSuccess(true);
     $response->addJSON('message', PMA_Message::success($msg));
-    $response->addJSON('sql_query', PMA_Util::getMessage($msg, $sql_query, 'success'));
+    $response->addJSON(
+        'sql_query',
+        PMA_Util::getMessage($msg, $sql_query, 'success')
+    );
 } else if ($result == false) {
     $response = PMA_Response::getInstance();
     $response->isSuccess(false);
