@@ -11,6 +11,8 @@ $(function () {
         event.preventDefault();
         PMA_querywindow.focus();
     });
+
+    checkNumberOfFields();
 });
 
 /**
@@ -41,9 +43,9 @@ var PMA_commonParams = (function () {
             for (var i in obj) {
                 if (params[i] !== undefined && params[i] !== obj[i]) {
                     reload = true;
-                    if (i == 'db' || i == 'table') {
-                        updateNavigation = true;
-                    }
+                }
+                if (i == 'db' || i == 'table') {
+                    updateNavigation = true;
                 }
                 params[i] = obj[i];
             }
@@ -77,9 +79,9 @@ var PMA_commonParams = (function () {
             var updateNavigation = false;
             if (params[name] !== undefined && params[name] !== value) {
                 PMA_querywindow.refresh();
-                if (name == 'db' || name == 'table') {
-                    updateNavigation = true;
-                }
+            }
+            if (name == 'db' || name == 'table') {
+                updateNavigation = true;
             }
             params[name] = value;
             if (updateNavigation) {
@@ -198,13 +200,13 @@ var PMA_querywindow = (function ($, window) {
 
             if (! querywindow.closed && querywindow.location) {
                 var href = querywindow.location.href;
-                if (href != url
-                    && href != PMA_commonParams.get('pma_absolute_uri') + url
+                if (href != url &&
+                    href != PMA_commonParams.get('pma_absolute_uri') + url
                 ) {
                     if (PMA_commonParams.get('safari_browser')) {
-                        querywindow.location.href = targeturl;
+                        querywindow.location.href = url;
                     } else {
-                        querywindow.location.replace(targeturl);
+                        querywindow.location.replace(url);
                     }
                     querywindow.focus();
                 }
@@ -212,14 +214,14 @@ var PMA_querywindow = (function ($, window) {
                 querywindow = window.open(
                     url + '&init=1',
                     '',
-                    'toolbar=0,location=0,directories=0,status=1,'
-                    + 'menubar=0,scrollbars=yes,resizable=yes,'
-                    + 'width=' + PMA_commonParams.get('querywindow_width') + ','
-                    + 'height=' + PMA_commonParams.get('querywindow_height')
+                    'toolbar=0,location=0,directories=0,status=1,' +
+                    'menubar=0,scrollbars=yes,resizable=yes,' +
+                    'width=' + PMA_commonParams.get('querywindow_width') + ',' +
+                    'height=' + PMA_commonParams.get('querywindow_height')
                 );
             }
             if (! querywindow.opener) {
-               querywindow.opener = window.window;
+                querywindow.opener = window.window;
             }
             if (window.focus) {
                 querywindow.focus();
@@ -245,7 +247,7 @@ var PMA_querywindow = (function ($, window) {
                 var hiddenqueryform = querywindow
                     .document
                     .getElementById('hiddenqueryform');
-                if (hiddenqueryform.querydisplay_tab != 'sql' ) {
+                if (hiddenqueryform.querydisplay_tab != 'sql') {
                     hiddenqueryform.querydisplay_tab.value = "sql";
                     hiddenqueryform.sql_query.value = sql_query;
                     $(hiddenqueryform).addClass('disableAjax');
@@ -266,7 +268,7 @@ var PMA_querywindow = (function ($, window) {
         refresh: function (url) {
             if (! querywindow.closed && querywindow.location) {
                 var $form = $(querywindow.document).find('#sqlqueryform');
-                if ($form.find('#checkbox_lock:checked').length == 0) {
+                if ($form.find('#checkbox_lock:checked').length === 0) {
                     PMA_querywindow.open(url);
                 }
             }
@@ -284,7 +286,7 @@ var PMA_querywindow = (function ($, window) {
         reload: function (db, table, sql_query) {
             if (! querywindow.closed && querywindow.location) {
                 var $form = $(querywindow.document).find('#sqlqueryform');
-                if ($form.find('#checkbox_lock:checked').length == 0) {
+                if ($form.find('#checkbox_lock:checked').length === 0) {
                     var $hiddenform = $(querywindow.document)
                         .find('#hiddenqueryform');
                     $hiddenform.find('input[name=db]').val(db);
