@@ -45,19 +45,39 @@ function appendNewUser(new_user_string, new_user_initial, new_user_initial_strin
 
     //Calculate the index for the new row
     var $curr_last_row = $("#usersForm").find('tbody').find('tr:last');
-    var $curr_first_row = $("#usersForm").find('tbody').find('tr:first');
-    var first_row_initial = $curr_first_row.find('label').html().substr(0, 1).toUpperCase();
-    var curr_shown_initial = $curr_last_row.find('label').html().substr(0, 1).toUpperCase();
-    var curr_last_row_index_string = $curr_last_row.find('input:checkbox').attr('id').match(/\d+/)[0];
-    var curr_last_row_index = parseFloat(curr_last_row_index_string);
-    var new_last_row_index = curr_last_row_index + 1;
+    if ($curr_last_row.length) {
+        // at least one tr exists inside the tbody
+        var $curr_first_row = $("#usersForm").find('tbody').find('tr:first');
+        var $first_row_label = $curr_first_row.find('label');
+        if ($first_row_label.length) {
+            var first_row_initial = $first_row_label.html().substr(0, 1).toUpperCase();
+            var curr_shown_initial = $curr_last_row.find('label').html().substr(0, 1).toUpperCase();
+            var curr_last_row_index_string = $curr_last_row.find('input:checkbox').attr('id').match(/\d+/)[0];
+            var curr_last_row_index = parseFloat(curr_last_row_index_string);
+            var new_last_row_index = curr_last_row_index + 1;
+            var is_show_all = (first_row_initial != curr_shown_initial) ? true : false;
+            var $insert_position = $curr_last_row;
+            var dummy_tr_inserted = false;
+        }
+    } else {
+        // no tr exists inside the tbody
+        var $tbody = $("#usersForm").find('tbody');
+        // append a dummy tr
+        $tbody.append('<tr></tr>');
+        var dummy_tr_inserted = true;
+        var $insert_position = $tbody.find('tr:first');
+        var is_show_all = true;
+        //todo: the case when the new user's initial does not match
+        //      the currently selected initial
+        var curr_shown_initial = '';
+        var new_last_row_index = 0;
+    }
     var new_last_row_id = 'checkbox_sel_users_' + new_last_row_index;
-    var is_show_all = (first_row_initial != curr_shown_initial) ? true : false;
 
     //Append to the table and set the id/names correctly
     if ((curr_shown_initial == new_user_initial) || is_show_all) {
         $(new_user_string)
-        .insertAfter($curr_last_row)
+        .insertAfter($insert_position)
         .find('input:checkbox')
         .attr('id', new_last_row_id)
         .val(function () {
@@ -70,6 +90,11 @@ function appendNewUser(new_user_string, new_user_initial, new_user_initial_strin
         .end();
     }
 
+    if (dummy_tr_inserted) {
+        // remove the dummy tr
+        $tbody.find('tr:first').remove();
+    }
+
     //Let us sort the table alphabetically
     $("#usersForm").find('tbody').PMA_sort_table('label');
 
@@ -88,7 +113,7 @@ function addUser($form)
 
     //We also need to post the value of the submit button in order to get this to work correctly
     $.post($form.attr('action'), $form.serialize() + "&adduser_submit=" + $("input[name=adduser_submit]").val(), function (data) {
-        if (data.success === true) {
+        if (typeof data !== 'undefined' && data.success === true) {
             // Refresh navigation, if we created a database with the name
             // that is the same as the username of the new user
             if ($('#add_user_dialog #createdb-1:checked').length) {
@@ -223,7 +248,7 @@ AJAX.registerOnload('server_privileges.js', function () {
         var $msgbox = PMA_ajaxShowMessage();
 
         $.get($(this).attr("href"), {'ajax_request': true}, function (data) {
-            if (data.success === true) {
+            if (typeof data !== 'undefined' && data.success === true) {
                 $('#page_content').hide();
                 var $div = $('#add_user_dialog');
                 if ($div.length === 0) {
@@ -277,7 +302,7 @@ AJAX.registerOnload('server_privileges.js', function () {
         var $form = $("#usersForm");
 
         $.post($form.attr('action'), $form.serialize() + "&delete=" + $(this).val() + "&ajax_request=true", function (data) {
-            if (data.success === true) {
+            if (typeof data !== 'undefined' && data.success === true) {
                 PMA_ajaxShowMessage(data.message);
                 // Refresh navigation, if we droppped some databases with the name
                 // that is the same as the username of the deleted user
@@ -324,7 +349,7 @@ AJAX.registerOnload('server_privileges.js', function () {
                 'token': token
             },
             function (data) {
-                if (data.success === true) {
+                if (typeof data !== 'undefined' && data.success === true) {
                     PMA_ajaxRemoveMessage($msg);
                     var buttonOptions = {};
                     buttonOptions[PMA_messages.strGo] = function () {
@@ -337,7 +362,7 @@ AJAX.registerOnload('server_privileges.js', function () {
                             $('#changeUserGroupDialog').find('form').serialize() + '&ajax_request=1',
                             function (data) {
                                 PMA_ajaxRemoveMessage($message);
-                                if (data.success === true) {
+                                if (typeof data !== 'undefined' && data.success === true) {
                                     $("#usersForm")
                                         .find('.current_row')
                                         .removeClass('current_row')
@@ -409,7 +434,7 @@ AJAX.registerOnload('server_privileges.js', function () {
                 'token': token
             },
             function (data) {
-                if (data.success === true) {
+                if (typeof data !== 'undefined' && data.success === true) {
                     $('#page_content').hide();
                     var $div = $('#edit_user_dialog');
                     if ($div.length === 0) {
@@ -484,7 +509,7 @@ AJAX.registerOnload('server_privileges.js', function () {
         }
 
         $.post($t.attr('action'), $t.serialize() + '&' + curr_submit_name + '=' + curr_submit_value, function (data) {
-            if (data.success === true) {
+            if (typeof data !== 'undefined' && data.success === true) {
                 $('#page_content').show();
                 $("#edit_user_dialog").remove();
 
@@ -566,7 +591,7 @@ AJAX.registerOnload('server_privileges.js', function () {
             $(this.form).prop('action'),
             $(this.form).serialize() + '&submit_mult=export&ajax_request=true',
             function (data) {
-                if (data.success === true) {
+                if (typeof data !== 'undefined' && data.success === true) {
                     var $ajaxDialog = $('<div />')
                     .append(data.message)
                     .dialog({
@@ -622,7 +647,7 @@ AJAX.registerOnload('server_privileges.js', function () {
             $(this).dialog("close");
         };
         $.get($(this).attr('href'), {'ajax_request': true}, function (data) {
-            if (data.success === true) {
+            if (typeof data !== 'undefined' && data.success === true) {
                 var $ajaxDialog = $('<div />')
                 .append(data.message)
                 .dialog({
@@ -664,7 +689,7 @@ AJAX.registerOnload('server_privileges.js', function () {
         event.preventDefault();
         var $msgbox = PMA_ajaxShowMessage();
         $.get($(this).attr('href'), {'ajax_request' : true}, function (data) {
-            if (data.success === true) {
+            if (typeof data !== 'undefined' && data.success === true) {
                 PMA_ajaxRemoveMessage($msgbox);
                 // This form is not on screen when first entering Privileges
                 // if there are more than 50 users
