@@ -18,7 +18,9 @@ var prevScrollX = 0, fixedTop;
  */
 function PMA_urldecode(str)
 {
-    return decodeURIComponent(str.replace(/\+/g, '%20'));
+    if (typeof str !== 'undefined') {
+        return decodeURIComponent(str.replace(/\+/g, '%20'));
+    }
 }
 
 /**
@@ -29,7 +31,9 @@ function PMA_urldecode(str)
  */
 function PMA_urlencode(str)
 {
-    return encodeURIComponent(str).replace(/\%20/g, '+');
+    if (typeof str !== 'undefined') {
+        return encodeURIComponent(str).replace(/\%20/g, '+');
+    }
 }
 
 /**
@@ -97,6 +101,7 @@ AJAX.registerTeardown('sql.js', function () {
     $('th.column_heading.marker').die('click');
     $(window).unbind('scroll');
     $(".filter_rows").die("keyup");
+    $('body').off('click', '#resultsForm.ajax button[name="submit_mult"], #resultsForm.ajax input[name="submit_mult"]');
 });
 
 /**
@@ -119,7 +124,7 @@ AJAX.registerOnload('sql.js', function () {
     // Delete row from SQL results
     $('a.delete_row.ajax').live('click', function (e) {
         e.preventDefault();
-        var question = $.sprintf(PMA_messages.strDoYouReally, $(this).closest('td').find('div').text());
+        var question = $.sprintf(PMA_messages.strDoYouReally, escapeHtml($(this).closest('td').find('div').text()));
         var $link = $(this);
         $link.PMA_confirm(question, $link.attr('href'), function (url) {
             $msgbox = PMA_ajaxShowMessage();
@@ -284,7 +289,7 @@ AJAX.registerOnload('sql.js', function () {
         PMA_prepareForAjaxRequest($form);
 
         $.post($form.attr('action'), $form.serialize(), function (data) {
-            if (data.success === true) {
+            if (typeof data !== 'undefined' && data.success === true) {
                 // success happens if the query returns rows or not
                 //
                 // fade out previous messages, if any
@@ -373,7 +378,7 @@ AJAX.registerOnload('sql.js', function () {
                         }
                     }
                 }
-            } else if (data.success === false) {
+            } else if (typeof data !== 'undefined' && data.success === false) {
                 // show an error message that stays on screen
                 $('#sqlqueryform').before(data.error);
                 $sqlqueryresults.hide();
@@ -433,6 +438,18 @@ AJAX.registerOnload('sql.js', function () {
         $target_table.find("th.dummy_th").remove();
     });
     // Filter row handling. --ENDS--
+
+    /**
+     * Handles mutli submits of results browsing page such as edit, delete and export
+     */
+    $('body').on('click', '#resultsForm.ajax button[name="submit_mult"], #resultsForm.ajax input[name="submit_mult"]', function (e) {
+        e.preventDefault();
+        var $button = $(this);
+        var $form = $button.parent('form');
+        var submitData = $form.serialize() + '&ajax_request=true&ajax_page_request=true&submit_mult=' + $button.val();
+        PMA_ajaxShowMessage();
+        $.get($form.attr('action'), submitData, AJAX.responseHandler);
+    });
 }); // end $()
 
 /**
@@ -583,7 +600,7 @@ function rearrangeStickyColumns() {
     var $clonedHeader = $originalHeader.clone();
     // clone width per cell
     $clonedHeader.find("tr:first").children().width(function(i,val) {
-        return $originalColumns.eq(i).width();
+        return Math.floor($originalColumns.eq(i).width()) + 1;
     });
     $sticky_columns.empty().append($clonedHeader);
 }
