@@ -30,7 +30,7 @@ function zoomAndPan()
     g.setAttribute('transform', 'translate(' + x + ', ' + y + ') scale(' + scale + ')');
     var id;
     var circle;
-    $('circle.vector').each(function() {
+    $('circle.vector').each(function () {
         id = $(this).attr('id');
         circle = svg.getElementById(id);
         svg.change(circle, {
@@ -40,7 +40,7 @@ function zoomAndPan()
     });
 
     var line;
-    $('polyline.vector').each(function() {
+    $('polyline.vector').each(function () {
         id = $(this).attr('id');
         line = svg.getElementById(id);
         svg.change(line, {
@@ -49,7 +49,7 @@ function zoomAndPan()
     });
 
     var polygon;
-    $('path.vector').each(function() {
+    $('path.vector').each(function () {
         id = $(this).attr('id');
         polygon = svg.getElementById(id);
         svg.change(polygon, {
@@ -62,7 +62,7 @@ function zoomAndPan()
  * Initially loads either SVG or OSM visualization based on the choice.
  */
 function selectVisualization() {
-    if ($('#choice').prop('checked') != true) {
+    if ($('#choice').prop('checked') !== true) {
         $('#openlayersmap').hide();
     } else {
         $('#placeholder').hide();
@@ -90,7 +90,7 @@ function loadSVG() {
     var $placeholder = $('#placeholder');
 
     $placeholder.svg({
-        onLoad: function(svg_ref) {
+        onLoad: function (svg_ref) {
             svg = svg_ref;
         }
     });
@@ -180,7 +180,7 @@ function getRelativeCoords(e) {
 /**
  * Unbind all event handlers before tearing down a page
  */
-AJAX.registerTeardown('tbl_gis_visualization.js', function() {
+AJAX.registerTeardown('tbl_gis_visualization.js', function () {
     $('#choice').die('click');
     $('#placeholder').die('mousewheel');
     $('svg').die('dragstart');
@@ -197,15 +197,15 @@ AJAX.registerTeardown('tbl_gis_visualization.js', function() {
     $('.vector').unbind('mousemove').unbind('mouseout');
 });
 
-AJAX.registerOnload('tbl_gis_visualization.js', function() {
+AJAX.registerOnload('tbl_gis_visualization.js', function () {
 
     // If we are in GIS visualization, initialize it
     if ($('table.gis_table').length > 0) {
         initGISVisualization();
     }
 
-    $('#choice').live('click', function() {
-        if ($(this).prop('checked') == false) {
+    $('#choice').live('click', function () {
+        if ($(this).prop('checked') === false) {
             $('#placeholder').show();
             $('#openlayersmap').hide();
         } else {
@@ -214,12 +214,12 @@ AJAX.registerOnload('tbl_gis_visualization.js', function() {
         }
     });
 
-    $('#placeholder').live('mousewheel', function(event, delta) {
+    $('#placeholder').live('mousewheel', function (event, delta) {
         var relCoords = getRelativeCoords(event);
         if (delta > 0) {
             //zoom in
             scale *= zoomFactor;
-            // zooming in keeping the position under mouse pointer unmoved.            
+            // zooming in keeping the position under mouse pointer unmoved.
             x = relCoords.x - (relCoords.x - x) * zoomFactor;
             y = relCoords.y - (relCoords.y - y) * zoomFactor;
             zoomAndPan();
@@ -234,18 +234,20 @@ AJAX.registerOnload('tbl_gis_visualization.js', function() {
         return true;
     });
 
-    var dragX = 0; var dragY = 0;
-    $('svg').live('dragstart', function(event, dd) {
+    var dragX = 0;
+    var dragY = 0;
+
+    $('svg').live('dragstart', function (event, dd) {
         $('#placeholder').addClass('placeholderDrag');
         dragX = Math.round(dd.offsetX);
         dragY = Math.round(dd.offsetY);
     });
 
-    $('svg').live('mouseup', function(event) {
+    $('svg').live('mouseup', function (event) {
         $('#placeholder').removeClass('placeholderDrag');
     });
 
-    $('svg').live('drag', function(event, dd) {
+    $('svg').live('drag', function (event, dd) {
         newX = Math.round(dd.offsetX);
         x +=  newX - dragX;
         dragX = newX;
@@ -255,7 +257,7 @@ AJAX.registerOnload('tbl_gis_visualization.js', function() {
         zoomAndPan();
     });
 
-    $('#placeholder').live('dblclick', function(event) {
+    $('#placeholder').live('dblclick', function (event) {
         scale *= zoomFactor;
         // zooming in keeping the position under mouse pointer unmoved.
         var relCoords = getRelativeCoords(event);
@@ -264,7 +266,7 @@ AJAX.registerOnload('tbl_gis_visualization.js', function() {
         zoomAndPan();
     });
 
-    $('#zoom_in').live('click', function(e) {
+    $('#zoom_in').live('click', function (e) {
         e.preventDefault();
         //zoom in
         scale *= zoomFactor;
@@ -277,7 +279,7 @@ AJAX.registerOnload('tbl_gis_visualization.js', function() {
         zoomAndPan();
     });
 
-    $('#zoom_world').live('click', function(e) {
+    $('#zoom_world').live('click', function (e) {
         e.preventDefault();
         scale = 1;
         x = defaultX;
@@ -285,7 +287,7 @@ AJAX.registerOnload('tbl_gis_visualization.js', function() {
         zoomAndPan();
     });
 
-    $('#zoom_out').live('click', function(e) {
+    $('#zoom_out').live('click', function (e) {
         e.preventDefault();
         //zoom out
         scale /= zoomFactor;
@@ -298,37 +300,37 @@ AJAX.registerOnload('tbl_gis_visualization.js', function() {
         zoomAndPan();
     });
 
-    $('#left_arrow').live('click', function(e) {
+    $('#left_arrow').live('click', function (e) {
         e.preventDefault();
         x += 100;
         zoomAndPan();
     });
 
-    $('#right_arrow').live('click', function(e) {
+    $('#right_arrow').live('click', function (e) {
         e.preventDefault();
         x -= 100;
         zoomAndPan();
     });
 
-    $('#up_arrow').live('click', function(e) {
+    $('#up_arrow').live('click', function (e) {
         e.preventDefault();
         y += 100;
         zoomAndPan();
     });
 
-    $('#down_arrow').live('click', function(e) {
+    $('#down_arrow').live('click', function (e) {
         e.preventDefault();
         y -= 100;
         zoomAndPan();
     });
-    
+
     /**
      * Detect the mousemove event and show tooltips.
      */
-    $('.vector').bind('mousemove', function(event) {
+    $('.vector').bind('mousemove', function (event) {
         var contents = $.trim(escapeHtml($(this).attr('name')));
         $("#tooltip").remove();
-        if (contents != '') {
+        if (contents !== '') {
             $('<div id="tooltip">' + contents + '</div>').css({
                 position : 'absolute',
                 top : event.pageY + 10,
@@ -344,7 +346,7 @@ AJAX.registerOnload('tbl_gis_visualization.js', function() {
     /**
      * Detect the mouseout event and hide tooltips.
      */
-    $('.vector').bind('mouseout', function(event) {
+    $('.vector').bind('mouseout', function (event) {
         $("#tooltip").remove();
     });
 });
