@@ -1,4 +1,4 @@
-// todo: change the axis
+// TODO: change the axis
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  ** @fileoverview JavaScript functions used on tbl_select.php
@@ -12,7 +12,7 @@
  **  Display Help/Info
  **/
 function displayHelp() {
-    PMA_ajaxShowMessage(PMA_messages['strDisplayHelp'], 10000);
+    PMA_ajaxShowMessage(PMA_messages.strDisplayHelp, 10000);
 }
 
 /**
@@ -20,7 +20,7 @@ function displayHelp() {
  ** @param array
  **/
 Array.max = function (array) {
-    return Math.max.apply( Math, array );
+    return Math.max.apply(Math, array);
 };
 
 /**
@@ -28,7 +28,7 @@ Array.max = function (array) {
  ** @param array
  **/
 Array.min = function (array) {
-    return Math.min.apply( Math, array );
+    return Math.min.apply(Math, array);
 };
 
 /**
@@ -57,7 +57,9 @@ function isEmpty(obj) {
  ** @param type Sring  Field type(datetime/timestamp/time/date)
  **/
 function getTimeStamp(val, type) {
-    if (type.toString().search(/datetime/i) != -1 || type.toString().search(/timestamp/i) != -1) {
+    if (type.toString().search(/datetime/i) != -1 ||
+        type.toString().search(/timestamp/i) != -1
+    ) {
         return $.datepicker.parseDateTime('yy-mm-dd', 'HH:mm:ss', val);
     }
     else if (type.toString().search(/time/i) != -1) {
@@ -73,10 +75,14 @@ function getTimeStamp(val, type) {
  ** @param field: field type (as in database structure)
  **/
 function getType(field) {
-    if (field.toString().search(/int/i) != -1 || field.toString().search(/decimal/i) != -1
-        || field.toString().search(/year/i) != -1) {
+    if (field.toString().search(/int/i) != -1 ||
+        field.toString().search(/decimal/i) != -1 ||
+        field.toString().search(/year/i) != -1
+    ) {
         return 'numeric';
-    } else if (field.toString().search(/time/i) != -1 || field.toString().search(/date/i) != -1) {
+    } else if (field.toString().search(/time/i) != -1 ||
+        field.toString().search(/date/i) != -1
+    ) {
         return 'time';
     } else {
         return 'text';
@@ -89,8 +95,8 @@ function getType(field) {
 function getCord(arr) {
     var newCord = [];
     var original = $.extend(true, [], arr);
-    var arr = jQuery.unique(arr).sort();
-    $.each(original, function(index, value) {
+    arr = jQuery.unique(arr).sort();
+    $.each(original, function (index, value) {
         newCord.push(jQuery.inArray(value, arr));
     });
     return [newCord, arr, original];
@@ -100,14 +106,14 @@ function getCord(arr) {
  ** Scrolls the view to the display section
  **/
 function scrollToChart() {
-   var x = $('#dataDisplay').offset().top - 100; // 100 provides buffer in viewport
-   $('html,body').animate({scrollTop: x}, 500);
+    var x = $('#dataDisplay').offset().top - 100; // 100 provides buffer in viewport
+    $('html,body').animate({scrollTop: x}, 500);
 }
 
 /**
  * Unbind all event handlers before tearing down a page
  */
-AJAX.registerTeardown('tbl_zoom_plot_jqplot.js', function() {
+AJAX.registerTeardown('tbl_zoom_plot_jqplot.js', function () {
     $('#tableid_0').unbind('change');
     $('#tableid_1').unbind('change');
     $('#tableid_2').unbind('change');
@@ -120,7 +126,7 @@ AJAX.registerTeardown('tbl_zoom_plot_jqplot.js', function() {
     $('div#querychart').unbind('jqplotDataClick');
 });
 
-AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
+AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function () {
     var cursorMode = ($("input[name='mode']:checked").val() == 'edit') ? 'crosshair' : 'pointer';
     var currentChart = null;
     var searchedDataKey = null;
@@ -143,9 +149,9 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
      **/
 
     // first column choice corresponds to the X axis
-    $('#tableid_0').change(function() {
+    $('#tableid_0').change(function () {
         //AJAX request for field type, collation, operators, and value field
-        $.post('tbl_zoom_select.php',{
+        $.post('tbl_zoom_select.php', {
             'ajax_request' : true,
             'change_tbl_info' : true,
             'db' : PMA_commonParams.get('db'),
@@ -153,23 +159,23 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
             'field' : $('#tableid_0').val(),
             'it' : 0,
             'token' : PMA_commonParams.get('token')
-        },function(data) {
+        }, function (data) {
             $('#tableFieldsId tr:eq(1) td:eq(0)').html(data.field_type);
             $('#tableFieldsId tr:eq(1) td:eq(1)').html(data.field_collation);
             $('#tableFieldsId tr:eq(1) td:eq(2)').html(data.field_operators);
             $('#tableFieldsId tr:eq(1) td:eq(3)').html(data.field_value);
-        xLabel = $('#tableid_0').val();
-        $('#types_0').val(data.field_type);
-        xType = data.field_type;
-        $('#collations_0').val(data.field_collations);
-        addDateTimePicker();
+            xLabel = $('#tableid_0').val();
+            $('#types_0').val(data.field_type);
+            xType = data.field_type;
+            $('#collations_0').val(data.field_collations);
+            addDateTimePicker();
         });
     });
 
     // second column choice corresponds to the Y axis
-    $('#tableid_1').change(function() {
+    $('#tableid_1').change(function () {
         //AJAX request for field type, collation, operators, and value field
-    $.post('tbl_zoom_select.php',{
+        $.post('tbl_zoom_select.php', {
             'ajax_request' : true,
             'change_tbl_info' : true,
             'db' : PMA_commonParams.get('db'),
@@ -177,22 +183,22 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
             'field' : $('#tableid_1').val(),
             'it' : 1,
             'token' : PMA_commonParams.get('token')
-        },function(data) {
+        }, function (data) {
             $('#tableFieldsId tr:eq(3) td:eq(0)').html(data.field_type);
             $('#tableFieldsId tr:eq(3) td:eq(1)').html(data.field_collation);
             $('#tableFieldsId tr:eq(3) td:eq(2)').html(data.field_operators);
             $('#tableFieldsId tr:eq(3) td:eq(3)').html(data.field_value);
-        yLabel = $('#tableid_1').val();
-        $('#types_1').val(data.field_type);
-        yType = data.field_type;
-        $('#collations_1').val(data.field_collations);
-        addDateTimePicker();
+            yLabel = $('#tableid_1').val();
+            $('#types_1').val(data.field_type);
+            yType = data.field_type;
+            $('#collations_1').val(data.field_collations);
+            addDateTimePicker();
         });
     });
 
-    $('#tableid_2').change(function() {
+    $('#tableid_2').change(function () {
         //AJAX request for field type, collation, operators, and value field
-    $.post('tbl_zoom_select.php',{
+        $.post('tbl_zoom_select.php', {
             'ajax_request' : true,
             'change_tbl_info' : true,
             'db' : PMA_commonParams.get('db'),
@@ -200,20 +206,20 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
             'field' : $('#tableid_2').val(),
             'it' : 2,
             'token' : PMA_commonParams.get('token')
-        },function(data) {
+        }, function (data) {
             $('#tableFieldsId tr:eq(6) td:eq(0)').html(data.field_type);
             $('#tableFieldsId tr:eq(6) td:eq(1)').html(data.field_collation);
             $('#tableFieldsId tr:eq(6) td:eq(2)').html(data.field_operators);
             $('#tableFieldsId tr:eq(6) td:eq(3)').html(data.field_value);
-        $('#types_2').val(data.field_type);
-        $('#collations_2').val(data.field_collations);
-        addDateTimePicker();
+            $('#types_2').val(data.field_type);
+            $('#collations_2').val(data.field_collations);
+            addDateTimePicker();
         });
     });
 
-    $('#tableid_3').change(function() {
+    $('#tableid_3').change(function () {
         //AJAX request for field type, collation, operators, and value field
-    $.post('tbl_zoom_select.php',{
+        $.post('tbl_zoom_select.php', {
             'ajax_request' : true,
             'change_tbl_info' : true,
             'db' : PMA_commonParams.get('db'),
@@ -221,25 +227,25 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
             'field' : $('#tableid_3').val(),
             'it' : 3,
             'token' : PMA_commonParams.get('token')
-        },function(data) {
+        }, function (data) {
             $('#tableFieldsId tr:eq(8) td:eq(0)').html(data.field_type);
             $('#tableFieldsId tr:eq(8) td:eq(1)').html(data.field_collation);
             $('#tableFieldsId tr:eq(8) td:eq(2)').html(data.field_operators);
             $('#tableFieldsId tr:eq(8) td:eq(3)').html(data.field_value);
-        $('#types_3').val(data.field_type);
-        $('#collations_3').val(data.field_collations);
-        addDateTimePicker();
+            $('#types_3').val(data.field_type);
+            $('#collations_3').val(data.field_collations);
+            addDateTimePicker();
         });
     });
 
     /**
      * Input form validation
      **/
-    $('#inputFormSubmitId').click(function() {
-        if ($('#tableid_0').get(0).selectedIndex == 0 || $('#tableid_1').get(0).selectedIndex == 0) {
-            PMA_ajaxShowMessage(PMA_messages['strInputNull']);
+    $('#inputFormSubmitId').click(function () {
+        if ($('#tableid_0').get(0).selectedIndex === 0 || $('#tableid_1').get(0).selectedIndex === 0) {
+            PMA_ajaxShowMessage(PMA_messages.strInputNull);
         } else if (xLabel == yLabel) {
-            PMA_ajaxShowMessage(PMA_messages['strSameInputs']);
+            PMA_ajaxShowMessage(PMA_messages.strSameInputs);
         }
     });
 
@@ -253,18 +259,18 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
         .hide();
 
     $('#togglesearchformlink')
-        .html(PMA_messages['strShowSearchCriteria'])
-        .bind('click', function() {
+        .html(PMA_messages.strShowSearchCriteria)
+        .bind('click', function () {
             var $link = $(this);
             $('#zoom_search_form').slideToggle();
-            if ($link.text() == PMA_messages['strHideSearchCriteria']) {
-                $link.text(PMA_messages['strShowSearchCriteria']);
+            if ($link.text() == PMA_messages.strHideSearchCriteria) {
+                $link.text(PMA_messages.strShowSearchCriteria);
             } else {
-                $link.text(PMA_messages['strHideSearchCriteria']);
+                $link.text(PMA_messages.strHideSearchCriteria);
             }
-         // avoid default click action
-        return false;
-     });
+            // avoid default click action
+            return false;
+        });
 
     /**
      ** Set dialog properties for the data display form
@@ -273,7 +279,7 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
     /*
      * Handle saving of a row in the editor
      */
-    buttonOptions[PMA_messages['strSave']] = function () {
+    buttonOptions[PMA_messages.strSave] = function () {
         //Find changed values by comparing form values with selectedRow Object
         var newValues = {};//Stores the values changed from original
         var sqlTypes = {};
@@ -285,7 +291,7 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
             var oldVal = selectedRow[key];
             var newVal = ($('#edit_fields_null_id_' + it).prop('checked')) ? null : $('#edit_fieldID_' + it).val();
             if (newVal instanceof Array) { // when the column is of type SET
-                newVal =  $('#edit_fieldID_' + it).map(function(){
+                newVal =  $('#edit_fieldID_' + it).map(function () {
                     return $(this).val();
                 }).get().join(",");
             }
@@ -303,6 +309,8 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
             var $input = $('#edit_fieldID_' + it);
             if ($input.hasClass('bit')) {
                 sqlTypes[key] = 'bit';
+            } else {
+                sqlTypes[key] = null;
             }
             it++;
         } //End data update
@@ -320,10 +328,10 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
                     series[0][searchedDataKey][0] =
                         getTimeStamp(selectedRow[xLabel], $('#types_0').val());
                 } else {
-                    // todo: text values
+                    // TODO: text values
                 }
                 currentChart.series[0].data = series[0];
-                // todo: axis changing
+                // TODO: axis changing
                 currentChart.replot();
 
             }
@@ -336,10 +344,10 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
                     series[0][searchedDataKey][1] =
                         getTimeStamp(selectedRow[yLabel], $('#types_1').val());
                 } else {
-                    // todo: text values
+                    // TODO: text values
                 }
                 currentChart.series[0].data = series[0];
-                // todo: axis changing
+                // TODO: axis changing
                 currentChart.replot();
             }
         } //End plot update
@@ -348,21 +356,21 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
         if (!isEmpty(newValues)) {
             var sql_query = 'UPDATE `' + PMA_commonParams.get('table') + '` SET ';
             for (key in newValues) {
-                sql_query += '`' + key + '`=' ;
+                sql_query += '`' + key + '`=';
                 var value = newValues[key];
 
                 // null
-                if (value == null) {
+                if (value === null) {
                     sql_query += 'NULL, ';
 
                 // empty
-                } else if ($.trim(value) == '') {
+                } else if ($.trim(value) === '') {
                     sql_query += "'', ";
 
                 // other
                 } else {
                     // type explicitly identified
-                    if (sqlTypes[key] != null) {
+                    if (sqlTypes[key] !== null) {
                         if (sqlTypes[key] == 'bit') {
                             sql_query += "b'" + value + "', ";
                         }
@@ -376,8 +384,9 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
                     }
                 }
             }
+            // remove two extraneous characters ', '
             sql_query = sql_query.substring(0, sql_query.length - 2);
-            sql_query += ' WHERE ' + PMA_urldecode(searchedData[searchedDataKey]['where_clause']);
+            sql_query += ' WHERE ' + PMA_urldecode(searchedData[searchedDataKey].where_clause);
 
             //Post SQL query to sql.php
             $.post('sql.php', {
@@ -386,23 +395,23 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
                     'ajax_request' : true,
                     'sql_query' : sql_query,
                     'inline_edit' : false
-                }, function(data) {
-                    if (data.success == true) {
+                }, function (data) {
+                    if (typeof data !== 'undefined' && data.success === true) {
                         $('#sqlqueryresults').html(data.sql_query);
                         $("#sqlqueryresults").trigger('appendAnchor');
                     } else {
                         PMA_ajaxShowMessage(data.error, false);
                     }
-            }); //End $.post
+                }); //End $.post
         }//End database update
         $("#dataDisplay").dialog('close');
     };
-    buttonOptions[PMA_messages['strCancel']] = function () {
+    buttonOptions[PMA_messages.strCancel] = function () {
         $(this).dialog('close');
     };
     $("#dataDisplay").dialog({
         autoOpen: false,
-        title: PMA_messages['strDataPointContent'],
+        title: PMA_messages.strDataPointContent,
         modal: true,
         buttons: buttonOptions,
         width: $('#dataDisplay').width() + 80,
@@ -418,8 +427,8 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
     $("#dataDisplay").find(':input').live('keydown', function (e) {
         if (e.which === 13) { // 13 is the ENTER key
             e.preventDefault();
-            if (typeof buttonOptions[PMA_messages['strSave']] === 'function') {
-                buttonOptions[PMA_messages['strSave']].call();
+            if (typeof buttonOptions[PMA_messages.strSave] === 'function') {
+                buttonOptions[PMA_messages.strSave].call();
             }
         }
     });
@@ -429,12 +438,12 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
      * Generate plot using jqplot
      */
 
-    if (searchedData != null) {
+    if (searchedData !== null) {
         $('#zoom_search_form')
          .slideToggle()
          .hide();
         $('#togglesearchformlink')
-         .text(PMA_messages['strShowSearchCriteria']);
+         .text(PMA_messages.strShowSearchCriteria);
         $('#togglesearchformdiv').show();
         var selectedRow;
         var colorCodes = ['#FF0000', '#00FFFF', '#0000FF', '#0000A0', '#FF0080', '#800080', '#FFFF00', '#00FF00', '#FF00FF'];
@@ -447,6 +456,9 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
         var xMin; // xAxis extreme min
         var yMax; // yAxis extreme max
         var yMin; // yAxis extreme min
+        var xVal;
+        var yVal;
+        var format;
 
         var options = {
             series: [
@@ -483,7 +495,7 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
         };
 
         // If data label is not set, do not show tooltips
-        if (dataLabel == '') {
+        if (dataLabel === '') {
             options.highlighter.show = false;
         }
 
@@ -496,18 +508,17 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
 
         if (xType == 'time') {
             var originalXType = $('#types_0').val();
-            var format;
             if (originalXType == 'date') {
                 format = '%Y-%m-%d';
             }
-            // todo: does not seem to work
+            // TODO: does not seem to work
             //else if (originalXType == 'time') {
               //  format = '%H:%M';
             //} else {
             //    format = '%Y-%m-%d %H:%M';
             //}
             $.extend(options.axes.xaxis, {
-                renderer:$.jqplot.DateAxisRenderer,
+                renderer: $.jqplot.DateAxisRenderer,
                 tickOptions: {
                     formatString: format
                 }
@@ -515,30 +526,29 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
         }
         if (yType == 'time') {
             var originalYType = $('#types_1').val();
-            var format;
             if (originalYType == 'date') {
                 format = '%Y-%m-%d';
             }
             $.extend(options.axes.yaxis, {
-                renderer:$.jqplot.DateAxisRenderer,
+                renderer: $.jqplot.DateAxisRenderer,
                 tickOptions: {
                     formatString: format
                 }
             });
         }
 
-        $.each(searchedData, function(key, value) {
+        $.each(searchedData, function (key, value) {
             if (xType == 'numeric') {
-                var xVal = parseFloat(value[xLabel]);
+                xVal = parseFloat(value[xLabel]);
             }
             if (xType == 'time') {
-                var xVal = getTimeStamp(value[xLabel], originalXType);
+                xVal = getTimeStamp(value[xLabel], originalXType);
             }
             if (yType == 'numeric') {
-                var yVal = parseFloat(value[yLabel]);
+                yVal = parseFloat(value[yLabel]);
             }
             if (yType == 'time') {
-                var yVal = getTimeStamp(value[yLabel], originalYType);
+                yVal = getTimeStamp(value[yLabel], originalYType);
             }
             series[0].push([
                 xVal,
@@ -546,7 +556,7 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
                 // extra Y values
                 value[dataLabel], // for highlighter
                                   // (may set an undefined value)
-                value['where_clause'], // for click on point
+                value.where_clause, // for click on point
                 key               // key from searchedData
             ]);
         });
@@ -557,21 +567,21 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
         currentChart = $.jqplot('querychart', series, options);
         currentChart.resetZoom();
 
-        $('button.button-reset').click(function(event) {
+        $('button.button-reset').click(function (event) {
             event.preventDefault();
             currentChart.resetZoom();
         });
 
         $('div#resizer').resizable();
-        $('div#resizer').bind('resizestop', function(event, ui) {
+        $('div#resizer').bind('resizestop', function (event, ui) {
             // make room so that the handle will still appear
             $('div#querychart').height($('div#resizer').height() * 0.96);
             $('div#querychart').width($('div#resizer').width() * 0.96);
-            currentChart.replot( {resetAxes: true})
+            currentChart.replot({resetAxes: true});
         });
 
         $('div#querychart').bind('jqplotDataClick',
-            function(event, seriesIndex, pointIndex, data) {
+            function (event, seriesIndex, pointIndex, data) {
                 searchedDataKey = data[4]; // key from searchedData (global)
                 var field_id = 0;
                 var post_params = {
@@ -583,14 +593,14 @@ AJAX.registerOnload('tbl_zoom_plot_jqplot.js', function() {
                     'token' : PMA_commonParams.get('token')
                 };
 
-                $.post('tbl_zoom_select.php', post_params, function(data) {
+                $.post('tbl_zoom_select.php', post_params, function (data) {
                     // Row is contained in data.row_info,
                     // now fill the displayResultForm with row values
                     var key;
                     for (key in data.row_info) {
                         $field = $('#edit_fieldID_' + field_id);
                         $field_null = $('#edit_fields_null_id_' + field_id);
-                        if (data.row_info[key] == null) {
+                        if (data.row_info[key] === null) {
                             $field_null.prop('checked', true);
                             $field.val('');
                         } else {
