@@ -114,7 +114,7 @@ class PMA_Config
      */
     function checkSystem()
     {
-        $this->set('PMA_VERSION', '4.2.6');
+        $this->set('PMA_VERSION', '4.2.12');
         /**
          * @deprecated
          */
@@ -820,6 +820,12 @@ class PMA_Config
             $this->setSource($source);
         }
 
+        /**
+         * We check and set the font size at this point, to make the font size
+         * selector work also for users without a config.inc.php
+         */
+        $this->checkFontsize();
+
         if (! $this->checkConfigSource()) {
             return false;
         }
@@ -873,7 +879,6 @@ class PMA_Config
 
         $this->settings = PMA_arrayMergeRecursive($this->settings, $cfg);
         $this->checkPmaAbsoluteUri();
-        $this->checkFontsize();
 
         // Handling of the collation must be done after merging of $cfg
         // (from config.inc.php) so that $cfg['DefaultConnectionCollation']
@@ -1756,7 +1761,7 @@ class PMA_Config
         // for the case when there is no config file (this is supported)
         if (empty($current_size)) {
             if (isset($_COOKIE['pma_fontsize'])) {
-                $current_size = $_COOKIE['pma_fontsize'];
+                $current_size = htmlspecialchars($_COOKIE['pma_fontsize']);
             } else {
                 $current_size = '82%';
             }
