@@ -92,7 +92,7 @@ class PMA_DbSearch
      */
     private function _setSearchParams()
     {
-        $this->_tables_names_only = PMA_DBI_get_tables($this->_db);
+        $this->_tables_names_only = $GLOBALS['dbi']->getTables($this->_db);
 
         $this->_searchTypes = array(
             '1' => __('at least one of the words'),
@@ -103,7 +103,10 @@ class PMA_DbSearch
 
         if (empty($_REQUEST['criteriaSearchType'])
             || ! is_string($_REQUEST['criteriaSearchType'])
-            || ! array_key_exists($_REQUEST['criteriaSearchType'], $this->_searchTypes)
+            || ! array_key_exists(
+                $_REQUEST['criteriaSearchType'],
+                $this->_searchTypes
+            )
         ) {
             $this->_criteriaSearchType = 1;
             unset($_REQUEST['submit_search']);
@@ -153,8 +156,8 @@ class PMA_DbSearch
      *
      * @todo    can we make use of fulltextsearch IN BOOLEAN MODE for this?
      * PMA_backquote
-     * PMA_DBI_free_result
-     * PMA_DBI_fetch_assoc
+     * DatabaseInterface::freeResult
+     * DatabaseInterface::fetchAssoc
      * $GLOBALS['db']
      * explode
      * count
@@ -172,7 +175,9 @@ class PMA_DbSearch
         // Gets where clause for the query
         $where_clause = $this->_getWhereClause($table);
         // Builds complete queries
-        $sql['select_columns'] = $sqlstr_select . ' * ' . $sqlstr_from . $where_clause;
+        $sql = array();
+        $sql['select_columns'] = $sqlstr_select . ' * ' . $sqlstr_from
+            . $where_clause;
         // here, I think we need to still use the COUNT clause, even for
         // VIEWs, anyway we have a WHERE clause that should limit results
         $sql['select_count']  = $sqlstr_select . ' COUNT(*) AS `count`'
@@ -193,7 +198,7 @@ class PMA_DbSearch
     {
         $where_clause = '';
         // Columns to select
-        $allColumns = PMA_DBI_get_columns($GLOBALS['db'], $table);
+        $allColumns = $GLOBALS['dbi']->getColumns($GLOBALS['db'], $table);
         $likeClauses = array();
         // Based on search type, decide like/regex & '%'/''
         $like_or_regex   = (($this->_criteriaSearchType == 4) ? 'REGEXP' : 'LIKE');
@@ -277,7 +282,7 @@ class PMA_DbSearch
             // Gets the SQL statements
             $newsearchsqls = $this->_getSearchSqls($each_table);
             // Executes the "COUNT" statement
-            $res_cnt = PMA_DBI_fetch_value($newsearchsqls['select_count']);
+            $res_cnt = $GLOBALS['dbi']->fetchValue($newsearchsqls['select_count']);
             $num_search_result_total += $res_cnt;
             // Gets the result row's HTML for a table
             $html_output .= $this->_getResultsRow(
@@ -337,16 +342,16 @@ class PMA_DbSearch
         // Displays browse/delete link if result count > 0
         if ($res_cnt > 0) {
             $this_url_params['sql_query'] = $newsearchsqls['select_columns'];
-            $browse_result_path = 'sql.php' . PMA_generate_common_url($this_url_params);
-            $html_output .= '<td><a name="browse_search" href="'
+            $browse_result_path = 'sql.php' . PMA_URL_getCommon($this_url_params);
+            $html_output .= '<td><a name="browse_search" class="ajax" href="'
                 . $browse_result_path . '" onclick="loadResult(\''
                 . $browse_result_path . '\',\'' . $each_table . '\',\''
-                . PMA_generate_common_url($GLOBALS['db'], $each_table) . '\''
+                . PMA_URL_getCommon($GLOBALS['db'], $each_table) . '\''
                 . ');return false;" >'
                 . __('Browse') . '</a></td>';
             $this_url_params['sql_query'] = $newsearchsqls['delete'];
-            $delete_result_path = 'sql.php' . PMA_generate_common_url($this_url_params);
-            $html_output .= '<td><a name="delete_search" href="'
+            $delete_result_path = 'sql.php' . PMA_URL_getCommon($this_url_params);
+            $html_output .= '<td><a name="delete_search" class="ajax" href="'
                 . $delete_result_path . '" onclick="deleteResult(\''
                 . $delete_result_path . '\' , \''
                 . sprintf(
@@ -357,7 +362,7 @@ class PMA_DbSearch
                 . __('Delete') . '</a></td>';
         } else {
             $html_output .= '<td>&nbsp;</td>'
-                .'<td>&nbsp;</td>';
+                . '<td>&nbsp;</td>';
         }// end if else
         $html_output .= '</tr>';
         return $html_output;
@@ -376,7 +381,7 @@ class PMA_DbSearch
         $html_output .= '<form id="db_search_form"'
             . ' class="ajax"'
             . ' method="post" action="db_search.php" name="db_search">';
-        $html_output .= PMA_generate_common_hidden_inputs($GLOBALS['db']);
+        $html_output .= PMA_URL_getHiddenInputs($GLOBALS['db']);
         $html_output .= '<fieldset>';
         // set legend caption
         $html_output .= '<legend>' . __('Search in database') . '</legend>';
@@ -405,7 +410,7 @@ class PMA_DbSearch
                 ),
             '3' => __('the exact phrase'),
             '4' => __('as regular expression') . ' '
-                . PMA_Util::showMySQLDocu('Regexp', 'Regexp')
+                . PMA_Util::showMySQLDocu('Regexp')
         );
         // 4th parameter set to true to add line breaks
         // 5th parameter set to false to avoid htmlspecialchars() escaping
@@ -418,7 +423,8 @@ class PMA_DbSearch
         $html_output .= '<tr>';
         $html_output .= '<td class="right vtop">' . __('Inside tables:') . '</td>';
         $html_output .= '<td rowspan="2">';
-        $html_output .= '<select name="criteriaTables[]" size="6" multiple="multiple">';
+        $html_output .= '<select name="criteriaTables[]" size="6"'
+            . ' multiple="multiple">';
         foreach ($this->_tables_names_only as $each_table) {
             if (in_array($each_table, $this->_criteriaTables)) {
                 $is_selected = ' selected="selected"';
@@ -434,18 +440,23 @@ class PMA_DbSearch
         $html_output .= '</td></tr>';
         // Displays 'select all' and 'unselect all' links
         $alter_select = '<a href="#" '
-            . 'onclick="setSelectOptions(\'db_search\', \'criteriaTables[]\', true); return false;">'
+            . 'onclick="setSelectOptions(\'db_search\','
+            . ' \'criteriaTables[]\', true); return false;">'
             . __('Select All') . '</a> &nbsp;/&nbsp;';
         $alter_select .= '<a href="#" '
-            . 'onclick="setSelectOptions(\'db_search\', \'criteriaTables[]\', false); return false;">'
+            . 'onclick="setSelectOptions(\'db_search\','
+            . ' \'criteriaTables[]\', false); return false;">'
             . __('Unselect All') . '</a>';
-        $html_output .= '<tr><td class="right vbottom">' . $alter_select . '</td></tr>';
+        $html_output .= '<tr><td class="right vbottom">'
+            . $alter_select . '</td></tr>';
         // Inputbox for column name entry
         $html_output .= '<tr>';
         $html_output .= '<td class="right">' . __('Inside column:') . '</td>';
         $html_output .= '<td><input type="text" name="criteriaColumnName" size="60"'
             . 'value="'
-            . (! empty($this->_criteriaColumnName) ? htmlspecialchars($this->_criteriaColumnName) : '')
+            . (! empty($this->_criteriaColumnName)
+                ? htmlspecialchars($this->_criteriaColumnName)
+                : '')
             . '" /></td>';
         $html_output .= '</tr>';
         $html_output .= '</table>';
@@ -455,7 +466,8 @@ class PMA_DbSearch
             . __('Go') . '" id="buttonGo" />';
         $html_output .= '</fieldset>';
         $html_output .= '</form>';
-        $html_output .= $this->_getResultDivs();
+        $html_output .= '<div id="togglesearchformdiv">'
+            . '<a id="togglesearchformlink"></a></div>';
 
         return $html_output;
     }
@@ -465,7 +477,7 @@ class PMA_DbSearch
      *
      * @return string div tags
      */
-    private function _getResultDivs()
+    public function getResultDivs()
     {
         $html_output = '<!-- These two table-image and table-link elements display'
             . ' the table name in browse search results  -->';
@@ -479,8 +491,8 @@ class PMA_DbSearch
         $html_output .= '</div>';
         $html_output .= '<br class="clearfloat" />';
         $html_output .= '<div id="sqlqueryform">';
-        $html_output .= '<!-- this sqlqueryform div is used to load the delete form in'
-            . ' the db search -->';
+        $html_output .= '<!-- this sqlqueryform div is used to load the delete'
+            . ' form in the db search -->';
         $html_output .= '</div>';
         $html_output .= '<!--  toggle query box link-->';
         $html_output .= '<a id="togglequerybox"></a>';
