@@ -44,8 +44,6 @@ class PMA_Menu
      * @param int    $server Server id
      * @param string $db     Database name
      * @param string $table  Table name
-     *
-     * @return New PMA_Table
      */
     public function __construct($server, $db, $table)
     {
@@ -99,17 +97,65 @@ class PMA_Menu
     {
         $tabs = array();
         $url_params = array('db' => $this->_db);
+        $level = '';
+
         if (strlen($this->_table)) {
             $tabs = $this->_getTableTabs();
             $url_params['table'] = $this->_table;
+            $level = 'table';
         } else if (strlen($this->_db)) {
             $tabs = $this->_getDbTabs();
+            $level = 'db';
         } else {
             $tabs = $this->_getServerTabs();
+            $level = 'server';
+        }
+
+        $allowedTabs = $this->_getAllowedTabs($level);
+        foreach ($tabs as $key => $value) {
+            if (! array_key_exists($key, $allowedTabs)) {
+                unset($tabs[$key]);
+            }
         }
         return PMA_Util::getHtmlTabs($tabs, $url_params, 'topmenu', true);
     }
 
+    /**
+     * Returns a list of allowed tabs for the current user for the given level
+     *
+     * @param string $level 'server', 'db' or 'table' level
+     *
+     * @return array list of allowed tabs
+     */
+    private function _getAllowedTabs($level)
+    {
+        $allowedTabs = PMA_Util::getMenuTabList($level);
+        $cfgRelation = PMA_getRelationsParam();
+        if ($cfgRelation['menuswork']) {
+            $groupTable = PMA_Util::backquote($GLOBALS['cfg']['Server']['pmadb'])
+                . "."
+                . PMA_Util::backquote($GLOBALS['cfg']['Server']['usergroups']);
+            $userTable = PMA_Util::backquote($GLOBALS['cfg']['Server']['pmadb'])
+                . "." . PMA_Util::backquote($GLOBALS['cfg']['Server']['users']);
+
+            $sql_query = "SELECT `tab` FROM " . $groupTable
+                . " WHERE `allowed` = 'N'"
+                . " AND `tab` LIKE '" . $level . "%'"
+                . " AND `usergroup` = (SELECT usergroup FROM "
+                . $userTable . " WHERE `username` = '"
+                . PMA_Util::sqlAddSlashes($GLOBALS['cfg']['Server']['user']) . "')";
+
+            $result = PMA_queryAsControlUser($sql_query, false);
+            if ($result) {
+                while ($row = $GLOBALS['dbi']->fetchAssoc($result)) {
+                    $tabName = substr($row['tab'], strpos($row['tab'], '_') + 1);
+                    unset($allowedTabs[$tabName]);
+                }
+            }
+        }
+        return $allowedTabs;
+    }
+
     /**
      * Returns the breadcrumbs as HTML
      *
@@ -130,21 +176,13 @@ class PMA_Menu
         $item = '<a href="%1$s?%2$s" class="item">';
 
 
-        if (in_array(
-            $GLOBALS['cfg']['TabsMode'],
-            array('text', 'both')
-            )
-        ) {
+        if (PMA_Util::showText('TabsMode')) {
             $item .= '%4$s: ';
         }
         $item .= '%3$s</a>';
         $retval .= "<div id='floating_menubar'></div>";
         $retval .= "<div id='serverinfo'>";
-        if (in_array(
-            $GLOBALS['cfg']['TabsMode'],
-            array('icons', 'both')
-            )
-        ) { 
+        if (PMA_Util::showIcons('TabsMode')) {
             $retval .= PMA_Util::getImage(
                 's_host.png',
                 '',
@@ -154,18 +192,14 @@ class PMA_Menu
         $retval .= sprintf(
             $item,
             $GLOBALS['cfg']['DefaultTabServer'],
-            PMA_generate_common_url(),
+            PMA_URL_getCommon(),
             htmlspecialchars($server_info),
             __('Server')
         );
 
         if (strlen($this->_db)) {
             $retval .= $separator;
-            if (in_array(
-                $GLOBALS['cfg']['TabsMode'],
-                array('icons', 'both')
-                )
-            ) { 
+            if (PMA_Util::showIcons('TabsMode')) {
                 $retval .= PMA_Util::getImage(
                     's_db.png',
                     '',
@@ -175,7 +209,7 @@ class PMA_Menu
             $retval .= sprintf(
                 $item,
                 $GLOBALS['cfg']['DefaultTabDatabase'],
-                PMA_generate_common_url($this->_db),
+                PMA_URL_getCommon($this->_db),
                 htmlspecialchars($this->_db),
                 __('Database')
             );
@@ -187,11 +221,7 @@ class PMA_Menu
                 include './libraries/tbl_info.inc.php';
 
                 $retval .= $separator;
-                if (in_array(
-                    $GLOBALS['cfg']['TabsMode'],
-                    array('icons', 'both')
-                    )
-                ) { 
+                if (PMA_Util::showIcons('TabsMode')) {
                     $icon = $tbl_is_view ? 'b_views.png' : 's_tbl.png';
                     $retval .= PMA_Util::getImage(
                         $icon,
@@ -202,7 +232,7 @@ class PMA_Menu
                 $retval .= sprintf(
                     $item,
                     $GLOBALS['cfg']['DefaultTabTable'],
-                    PMA_generate_common_url($this->_db, $this->_table),
+                    PMA_URL_getCommon($this->_db, $this->_table),
                     str_replace(' ', '&nbsp;', htmlspecialchars($this->_table)),
                     $tbl_is_view ? __('View') : __('Table')
                 );
@@ -257,9 +287,9 @@ class PMA_Menu
      */
     private function _getTableTabs()
     {
-        $db_is_information_schema = PMA_is_system_schema($this->_db);
+        $db_is_system_schema = $GLOBALS['dbi']->isSystemSchema($this->_db);
         $tbl_is_view = PMA_Table::isView($this->_db, $this->_table);
-        $table_info_num_rows = PMA_Table::countRecords($this->_db, $this->_table);
+        $is_superuser = $GLOBALS['dbi']->isSuperuser();
 
         $tabs = array();
 
@@ -281,10 +311,10 @@ class PMA_Menu
         $tabs['search']['link'] = 'tbl_select.php';
         $tabs['search']['active'] = in_array(
             basename($GLOBALS['PMA_PHP_SELF']),
-            array('tbl_select.php', 'tbl_zoom_select.php')
+            array('tbl_select.php', 'tbl_zoom_select.php', 'tbl_find_replace.php')
         );
 
-        if (! $db_is_information_schema) {
+        if (! $db_is_system_schema) {
             $tabs['insert']['icon'] = 'b_insrow.png';
             $tabs['insert']['link'] = 'tbl_change.php';
             $tabs['insert']['text'] = __('Insert');
@@ -296,14 +326,26 @@ class PMA_Menu
         $tabs['export']['text'] = __('Export');
 
         /**
-         * Don't display "Import" and "Operations"
-         * for views and information_schema
+         * Don't display "Import" for views and information_schema
          */
-        if (! $tbl_is_view && ! $db_is_information_schema) {
+        if (! $tbl_is_view && ! $db_is_system_schema) {
             $tabs['import']['icon'] = 'b_tblimport.png';
             $tabs['import']['link'] = 'tbl_import.php';
             $tabs['import']['text'] = __('Import');
-
+        }
+        if ($is_superuser && ! PMA_DRIZZLE && ! $db_is_system_schema) {
+            $tabs['privileges']['link'] = 'server_privileges.php';
+            $tabs['privileges']['args']['checkprivsdb'] = $this->_db;
+            $tabs['privileges']['args']['checkprivstable'] = $this->_table;
+            // stay on table view
+            $tabs['privileges']['args']['viewing_mode'] = 'table';
+            $tabs['privileges']['text'] = __('Privileges');
+            $tabs['privileges']['icon'] = 's_rights.png';
+        }
+        /**
+         * Don't display "Operations" for views and information_schema
+         */
+        if (! $tbl_is_view && ! $db_is_system_schema) {
             $tabs['operation']['icon'] = 'b_tblops.png';
             $tabs['operation']['link'] = 'tbl_operations.php';
             $tabs['operation']['text'] = __('Operations');
@@ -313,9 +355,13 @@ class PMA_Menu
             $tabs['tracking']['text'] = __('Tracking');
             $tabs['tracking']['link'] = 'tbl_tracking.php';
         }
-        if (! $db_is_information_schema
+        if (! $db_is_system_schema
             && ! PMA_DRIZZLE
-            && PMA_Util::currentUserHasPrivilege('TRIGGER', $this->_db, $this->_table)
+            && PMA_Util::currentUserHasPrivilege(
+                'TRIGGER',
+                $this->_db,
+                $this->_table
+            )
             && ! $tbl_is_view
         ) {
             $tabs['triggers']['link'] = 'tbl_triggers.php';
@@ -326,7 +372,7 @@ class PMA_Menu
         /**
          * Views support a limited number of operations
          */
-        if ($tbl_is_view && ! $db_is_information_schema) {
+        if ($tbl_is_view && ! $db_is_system_schema) {
             $tabs['operation']['icon'] = 'b_tblops.png';
             $tabs['operation']['link'] = 'view_operations.php';
             $tabs['operation']['text'] = __('Operations');
@@ -342,9 +388,9 @@ class PMA_Menu
      */
     private function _getDbTabs()
     {
-        $db_is_information_schema = PMA_is_system_schema($this->_db);
-        $num_tables = count(PMA_DBI_get_tables($this->_db));
-        $is_superuser = PMA_isSuperuser();
+        $db_is_system_schema = $GLOBALS['dbi']->isSystemSchema($this->_db);
+        $num_tables = count($GLOBALS['dbi']->getTables($this->_db));
+        $is_superuser = $GLOBALS['dbi']->isSuperuser();
 
         /**
          * Gets the relation settings
@@ -358,7 +404,6 @@ class PMA_Menu
         $tabs['structure']['icon'] = 'b_props.png';
 
         $tabs['sql']['link'] = 'db_sql.php';
-        $tabs['sql']['args']['db_query_force'] = 1;
         $tabs['sql']['text'] = __('SQL');
         $tabs['sql']['icon'] = 'b_sql.png';
 
@@ -383,7 +428,7 @@ class PMA_Menu
             $tabs['export']['warning'] = __('Database seems to be empty!');
         }
 
-        if (! $db_is_information_schema) {
+        if (! $db_is_system_schema) {
             $tabs['import']['link'] = 'db_import.php';
             $tabs['import']['text'] = __('Import');
             $tabs['import']['icon'] = 'b_import.png';
@@ -394,7 +439,7 @@ class PMA_Menu
 
             if ($is_superuser && ! PMA_DRIZZLE) {
                 $tabs['privileges']['link'] = 'server_privileges.php';
-                $tabs['privileges']['args']['checkprivs'] = $this->_db;
+                $tabs['privileges']['args']['checkprivsdb'] = $this->_db;
                 // stay on database view
                 $tabs['privileges']['args']['viewing_mode'] = 'db';
                 $tabs['privileges']['text'] = __('Privileges');
@@ -428,7 +473,7 @@ class PMA_Menu
             $tabs['tracking']['link'] = 'db_tracking.php';
         }
 
-        if (! $db_is_information_schema && $cfgRelation['designerwork']) {
+        if (! $db_is_system_schema && $cfgRelation['designerwork']) {
             $tabs['designer']['text'] = __('Designer');
             $tabs['designer']['icon'] = 'b_relations.png';
             $tabs['designer']['link'] = 'pmd_general.php';
@@ -444,19 +489,17 @@ class PMA_Menu
      */
     private function _getServerTabs()
     {
-        $is_superuser = function_exists('PMA_isSuperuser') && PMA_isSuperuser();
+        $is_superuser = isset($GLOBALS['dbi']) && $GLOBALS['dbi']->isSuperuser();
         $binary_logs = null;
-        if (function_exists('PMA_DBI_fetch_result')
-            && (! defined('PMA_DRIZZLE') 
-                || (defined('PMA_DRIZZLE') && ! PMA_DRIZZLE)
-            )
-        ) {
-            $binary_logs = PMA_DBI_fetch_result(
+        $notDrizzle = ! defined('PMA_DRIZZLE')
+            || (defined('PMA_DRIZZLE') && ! PMA_DRIZZLE);
+        if (isset($GLOBALS['dbi']) && $notDrizzle) {
+            $binary_logs = $GLOBALS['dbi']->fetchResult(
                 'SHOW MASTER LOGS',
                 'Log_name',
                 null,
                 null,
-                PMA_DBI_QUERY_STORE
+                PMA_DatabaseInterface::QUERY_STORE
             );
         }
 
@@ -488,6 +531,11 @@ class PMA_Menu
             $tabs['rights']['icon'] = 's_rights.png';
             $tabs['rights']['link'] = 'server_privileges.php';
             $tabs['rights']['text'] = __('Users');
+            $tabs['rights']['active'] = in_array(
+                basename($GLOBALS['PMA_PHP_SELF']),
+                array('server_privileges.php', 'server_user_groups.php')
+            );
+            $tabs['rights']['args']['viewing_mode'] = 'server';
         }
 
         $tabs['export']['icon'] = 'b_export.png';
