@@ -12,7 +12,7 @@
  * Based on PMA_sanitize from sanitize.lib.php.
  *
  * @param string $lang_key key in $GLOBALS WITHOUT 'strSetup' prefix
- * @param mixed  $args,... arguments for sprintf
+ * @param mixed  $args     arguments for sprintf
  *
  * @return string
  */
@@ -35,13 +35,13 @@ function PMA_lang($lang_key, $args = null)
 /**
  * Returns translated field name/description or comment
  *
- * @param string $canonical_path
- * @param string $type  'name', 'desc' or 'cmt'
- * @param mixed  $default
+ * @param string $canonical_path path to handle
+ * @param string $type           'name', 'desc' or 'cmt'
+ * @param mixed  $default        default value
  *
  * @return string
  */
-function PMA_lang_name($canonical_path, $type = 'name', $default = 'key')
+function PMA_langName($canonical_path, $type = 'name', $default = 'key')
 {
     $lang_key = str_replace(
         array('Servers/1/', '/'),
