@@ -1,16 +1,14 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
+ * The BerkeleyDB storage engine
+ *
  * @package PhpMyAdmin-Engines
  */
 if (! defined('PHPMYADMIN')) {
     exit;
 }
 
-if (! defined('PHPMYADMIN')) {
-    exit;
-}
-
 /**
  * Load BDB class.
  */
@@ -21,7 +19,7 @@ require_once './libraries/engines/bdb.lib.php';
  *
  * @package PhpMyAdmin-Engines
  */
-class PMA_StorageEngine_berkeleydb extends PMA_StorageEngine_bdb
+class PMA_StorageEngine_Berkeleydb extends PMA_StorageEngine_Bdb
 {
 }
 
