@@ -1,6 +1,7 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
+ * The Innobase storage engine
  *
  * @package PhpMyAdmin-Engines
  */
@@ -8,20 +9,17 @@ if (! defined('PHPMYADMIN')) {
     exit;
 }
 
-if (! defined('PHPMYADMIN')) {
-    exit;
-}
-
 /**
  *
  */
 require_once './libraries/engines/innodb.lib.php';
 
 /**
+ * The Innobase storage engine
  *
  * @package PhpMyAdmin-Engines
  */
-class PMA_StorageEngine_innobase extends PMA_StorageEngine_innodb
+class PMA_StorageEngine_Innobase extends PMA_StorageEngine_Innodb
 {
 }
 ?>
