@@ -9,23 +9,19 @@ if (! defined('PHPMYADMIN')) {
     exit;
 }
 
-if (! defined('PHPMYADMIN')) {
-    exit;
-}
-
 /**
  * The MEMORY (HEAP) storage engine
  *
  * @package PhpMyAdmin-Engines
  */
-class PMA_StorageEngine_memory extends PMA_StorageEngine
+class PMA_StorageEngine_Memory extends PMA_StorageEngine
 {
     /**
      * Returns array with variable names dedicated to MEMORY storage engine
      *
      * @return array   variable names
      */
-    function getVariables()
+    public function getVariables()
     {
         return array(
             'max_heap_table_size' => array(
