@@ -9,23 +9,19 @@ if (! defined('PHPMYADMIN')) {
     exit;
 }
 
-if (! defined('PHPMYADMIN')) {
-    exit;
-}
-
 /**
  * The NDBCLUSTER storage engine
  *
  * @package PhpMyAdmin-Engines
  */
-class PMA_StorageEngine_ndbcluster extends PMA_StorageEngine
+class PMA_StorageEngine_Ndbcluster extends PMA_StorageEngine
 {
     /**
      * Returns array with variable names realted to NDBCLUSTER storage engine
      *
      * @return array   variable names
      */
-    function getVariables()
+    public function getVariables()
     {
         return array(
             'ndb_connectstring' => array(
@@ -39,7 +35,7 @@ class PMA_StorageEngine_ndbcluster extends PMA_StorageEngine
      *
      * @return string  SQL query LIKE pattern
      */
-    function getVariablesLikePattern()
+    public function getVariablesLikePattern()
     {
         return 'ndb\\_%';
     }
@@ -50,7 +46,7 @@ class PMA_StorageEngine_ndbcluster extends PMA_StorageEngine
      *
      * @return string  mysql helppage filename
      */
-    function getMysqlHelpPage()
+    public function getMysqlHelpPage()
     {
         return 'ndbcluster';
     }
