@@ -29,7 +29,7 @@ class Node_Column extends Node
     public function __construct($name, $type = Node::OBJECT, $is_group = false)
     {
         parent::__construct($name, $type, $is_group);
-        $this->icon  = PMA_Util::getImage('pause.png', '');
+        $this->icon  = PMA_Util::getImage('pause.png', __('Column'));
         $this->links = array(
             'text' => 'tbl_structure.php?server=' . $GLOBALS['server']
                     . '&amp;db=%3$s&amp;table=%2$s&amp;field=%1$s'
