@@ -9,12 +9,14 @@ if (! defined('PHPMYADMIN')) {
     exit;
 }
 
+require_once 'libraries/navigation/Nodes/Node_DatabaseChild.class.php';
+
 /**
  * Represents a event node in the navigation tree
  *
  * @package PhpMyAdmin-Navigation
  */
-class Node_Event extends Node
+class Node_Event extends Node_DatabaseChild
 {
     /**
      * Initialises the class
@@ -40,6 +42,16 @@ class Node_Event extends Node
         );
         $this->classes = 'event';
     }
+
+    /**
+     * Returns the type of the item represented by the node.
+     *
+     * @return string type of the item
+     */
+    protected function getItemType()
+    {
+        return 'event';
+    }
 }
 
 ?>
