@@ -244,12 +244,14 @@ class ExportOdt extends ExportPlugin
         global $what;
 
         // Gets the data from the database
-        $result = PMA_DBI_query($sql_query, null, PMA_DBI_QUERY_UNBUFFERED);
-        $fields_cnt = PMA_DBI_num_fields($result);
-        $fields_meta = PMA_DBI_get_fields_meta($result);
+        $result = $GLOBALS['dbi']->query(
+            $sql_query, null, PMA_DatabaseInterface::QUERY_UNBUFFERED
+        );
+        $fields_cnt = $GLOBALS['dbi']->numFields($result);
+        $fields_meta = $GLOBALS['dbi']->getFieldsMeta($result);
         $field_flags = array();
         for ($j = 0; $j < $fields_cnt; $j++) {
-            $field_flags[$j] = PMA_DBI_field_flags($result, $j);
+            $field_flags[$j] = $GLOBALS['dbi']->fieldFlags($result, $j);
         }
 
         $GLOBALS['odt_buffer'] .=
@@ -270,7 +272,7 @@ class ExportOdt extends ExportPlugin
                     '<table:table-cell office:value-type="string">'
                     . '<text:p>'
                         . htmlspecialchars(
-                            stripslashes(PMA_DBI_field_name($result, $i))
+                            stripslashes($GLOBALS['dbi']->fieldName($result, $i))
                         )
                     . '</text:p>'
                     . '</table:table-cell>';
@@ -279,7 +281,7 @@ class ExportOdt extends ExportPlugin
         } // end if
 
         // Format the data
-        while ($row = PMA_DBI_fetch_row($result)) {
+        while ($row = $GLOBALS['dbi']->fetchRow($result)) {
             $GLOBALS['odt_buffer'] .= '<table:table-row>';
             for ($j = 0; $j < $fields_cnt; $j++) {
                 if (! isset($row[$j]) || is_null($row[$j])) {
@@ -319,7 +321,7 @@ class ExportOdt extends ExportPlugin
             } // end for
             $GLOBALS['odt_buffer'] .= '</table:table-row>';
         } // end while
-        PMA_DBI_free_result($result);
+        $GLOBALS['dbi']->freeResult($result);
 
         $GLOBALS['odt_buffer'] .= '</table:table>';
 
@@ -340,7 +342,7 @@ class ExportOdt extends ExportPlugin
         /**
          * Gets fields properties
          */
-        PMA_DBI_select_db($db);
+        $GLOBALS['dbi']->selectDb($db);
 
         /**
          * Displays the table structure
@@ -368,7 +370,7 @@ class ExportOdt extends ExportPlugin
             . '</table:table-cell>'
             . '</table:table-row>';
 
-        $columns = PMA_DBI_get_columns($db, $view);
+        $columns = $GLOBALS['dbi']->getColumns($db, $view);
         foreach ($columns as $column) {
             $GLOBALS['odt_buffer'] .= $this->formatOneColumnDefinition($column);
             $GLOBALS['odt_buffer'] .= '</table:table-row>';
@@ -416,7 +418,7 @@ class ExportOdt extends ExportPlugin
         /**
          * Gets fields properties
          */
-        PMA_DBI_select_db($db);
+        $GLOBALS['dbi']->selectDb($db);
 
         // Check if we can use Relations
         if ($do_relation && ! empty($cfgRelation['relation'])) {
@@ -483,7 +485,7 @@ class ExportOdt extends ExportPlugin
         }
         $GLOBALS['odt_buffer'] .= '</table:table-row>';
 
-        $columns = PMA_DBI_get_columns($db, $table);
+        $columns = $GLOBALS['dbi']->getColumns($db, $table);
         foreach ($columns as $column) {
             $field_name = $column['Field'];
             $GLOBALS['odt_buffer'] .= $this->formatOneColumnDefinition($column);
@@ -569,7 +571,7 @@ class ExportOdt extends ExportPlugin
             . '</table:table-cell>'
             . '</table:table-row>';
 
-        $triggers = PMA_DBI_get_triggers($db, $table);
+        $triggers = $GLOBALS['dbi']->getTriggers($db, $table);
 
         foreach ($triggers as $trigger) {
             $GLOBALS['odt_buffer'] .= '<table:table-row>';
@@ -647,7 +649,7 @@ class ExportOdt extends ExportPlugin
             );
             break;
         case 'triggers':
-            $triggers = PMA_DBI_get_triggers($db, $table);
+            $triggers = $GLOBALS['dbi']->getTriggers($db, $table);
             if ($triggers) {
                 $GLOBALS['odt_buffer'] .=
                     '<text:h text:outline-level="2" text:style-name="Heading_2"'
@@ -715,8 +717,6 @@ class ExportOdt extends ExportPlugin
             } else {
                 $column['Default'] = '';
             }
-        } else {
-            $column['Default'] = $column['Default'];
         }
         $definition .= '<table:table-cell office:value-type="string">'
             . '<text:p>'
