@@ -188,8 +188,10 @@ class ExportTexytext extends ExportPlugin
         }
 
         // Gets the data from the database
-        $result      = PMA_DBI_query($sql_query, null, PMA_DBI_QUERY_UNBUFFERED);
-        $fields_cnt  = PMA_DBI_num_fields($result);
+        $result      = $GLOBALS['dbi']->query(
+            $sql_query, null, PMA_DatabaseInterface::QUERY_UNBUFFERED
+        );
+        $fields_cnt  = $GLOBALS['dbi']->numFields($result);
 
         // If required, get fields name at the first line
         if (isset($GLOBALS[$what . '_columns'])) {
@@ -197,7 +199,7 @@ class ExportTexytext extends ExportPlugin
             for ($i = 0; $i < $fields_cnt; $i++) {
                 $text_output .= '|'
                     . htmlspecialchars(
-                        stripslashes(PMA_DBI_field_name($result, $i))
+                        stripslashes($GLOBALS['dbi']->fieldName($result, $i))
                     );
             } // end for
             $text_output .= "\n|------\n";
@@ -207,7 +209,7 @@ class ExportTexytext extends ExportPlugin
         } // end if
 
         // Format the data
-        while ($row = PMA_DBI_fetch_row($result)) {
+        while ($row = $GLOBALS['dbi']->fetchRow($result)) {
             $text_output = '';
             for ($j = 0; $j < $fields_cnt; $j++) {
                 if (! isset($row[$j]) || is_null($row[$j])) {
@@ -227,7 +229,7 @@ class ExportTexytext extends ExportPlugin
                 return false;
             }
         } // end while
-        PMA_DBI_free_result($result);
+        $GLOBALS['dbi']->freeResult($result);
 
         return true;
     }
@@ -249,7 +251,7 @@ class ExportTexytext extends ExportPlugin
          * Get the unique keys in the table
          */
         $unique_keys = array();
-        $keys = PMA_DBI_get_table_indexes($db, $view);
+        $keys = $GLOBALS['dbi']->getTableIndexes($db, $view);
         foreach ($keys as $key) {
             if ($key['Non_unique'] == 0) {
                 $unique_keys[] = $key['Column_name'];
@@ -259,7 +261,7 @@ class ExportTexytext extends ExportPlugin
         /**
          * Gets fields properties
          */
-        PMA_DBI_select_db($db);
+        $GLOBALS['dbi']->selectDb($db);
 
         /**
          * Displays the table structure
@@ -272,7 +274,7 @@ class ExportTexytext extends ExportPlugin
             . '|' . __('Default')
             . "\n|------\n";
 
-        $columns = PMA_DBI_get_columns($db, $view);
+        $columns = $GLOBALS['dbi']->getColumns($db, $view);
         foreach ($columns as $column) {
             $text_output .= $this->formatOneColumnDefinition($column, $unique_keys);
             $text_output .= "\n";
@@ -323,7 +325,7 @@ class ExportTexytext extends ExportPlugin
          * Get the unique keys in the table
          */
         $unique_keys = array();
-        $keys        = PMA_DBI_get_table_indexes($db, $table);
+        $keys        = $GLOBALS['dbi']->getTableIndexes($db, $table);
         foreach ($keys as $key) {
             if ($key['Non_unique'] == 0) {
                 $unique_keys[] = $key['Column_name'];
@@ -333,7 +335,7 @@ class ExportTexytext extends ExportPlugin
         /**
          * Gets fields properties
          */
-        PMA_DBI_select_db($db);
+        $GLOBALS['dbi']->selectDb($db);
 
         // Check if we can use Relations
         if ($do_relation && ! empty($cfgRelation['relation'])) {
@@ -383,7 +385,7 @@ class ExportTexytext extends ExportPlugin
         }
         $text_output .= "\n|------\n";
 
-        $columns = PMA_DBI_get_columns($db, $table);
+        $columns = $GLOBALS['dbi']->getColumns($db, $table);
         foreach ($columns as $column) {
             $text_output .= $this->formatOneColumnDefinition($column, $unique_keys);
             $field_name = $column['Field'];
@@ -428,7 +430,7 @@ class ExportTexytext extends ExportPlugin
      */
     function getTriggers($db, $table)
     {
-        $text_output .= "|------\n";
+        $text_output = "|------\n";
         $text_output .= '|' . __('Column');
         $dump = "|------\n";
         $dump .= '|' . __('Name');
@@ -437,7 +439,7 @@ class ExportTexytext extends ExportPlugin
         $dump .= '|' . __('Definition');
         $dump .= "\n|------\n";
 
-        $triggers = PMA_DBI_get_triggers($db, $table);
+        $triggers = $GLOBALS['dbi']->getTriggers($db, $table);
 
         foreach ($triggers as $trigger) {
             $dump .= '|' . $trigger['name'];
@@ -493,7 +495,7 @@ class ExportTexytext extends ExportPlugin
 
         switch($export_mode) {
         case 'create_table':
-            $dump .= '== ' . __('Table structure for table') . ' ' .$table . "\n\n";
+            $dump .= '== ' . __('Table structure for table') . ' ' . $table . "\n\n";
             $dump .= $this->getTableDef(
                 $db, $table, $crlf, $error_url, $do_relation, $do_comments,
                 $do_mime, $dates
@@ -501,14 +503,14 @@ class ExportTexytext extends ExportPlugin
             break;
         case 'triggers':
             $dump = '';
-            $triggers = PMA_DBI_get_triggers($db, $table);
+            $triggers = $GLOBALS['dbi']->getTriggers($db, $table);
             if ($triggers) {
-                $dump .= '== ' . __('Triggers') . ' ' .$table . "\n\n";
+                $dump .= '== ' . __('Triggers') . ' ' . $table . "\n\n";
                 $dump .= $this->getTriggers($db, $table);
             }
             break;
         case 'create_view':
-            $dump .= '== ' . __('Structure for view') . ' ' .$table . "\n\n";
+            $dump .= '== ' . __('Structure for view') . ' ' . $table . "\n\n";
             $dump .= $this->getTableDef(
                 $db, $table, $crlf, $error_url, $do_relation, $do_comments,
                 $do_mime, $dates, true, true
@@ -516,7 +518,7 @@ class ExportTexytext extends ExportPlugin
             break;
         case 'stand_in':
             $dump .=  '== ' . __('Stand-in structure for view')
-                . ' ' .$table . "\n\n";
+                . ' ' . $table . "\n\n";
             // export a stand-in definition to resolve view dependencies
             $dump .= $this->getTableDefStandIn($db, $table, $crlf);
         } // end switch
