@@ -102,6 +102,10 @@ class ExportXml extends ExportPlugin
         $structure->setText(__('Object creation options (all are recommended)'));
         // create primary items and add them to the group
         if (! PMA_DRIZZLE) {
+            $leaf = new BoolPropertyItem();
+            $leaf->setName("export_events");
+            $leaf->setText(__('Events'));
+            $structure->addProperty($leaf);
             $leaf = new BoolPropertyItem();
             $leaf->setName("export_functions");
             $leaf->setText(__('Functions'));
@@ -188,15 +192,15 @@ class ExportXml extends ExportPlugin
                .  '- version ' . PMA_VERSION . $crlf
                .  '- http://www.phpmyadmin.net' . $crlf
                .  '-' . $crlf
-               .  '- ' . __('Host') . ': ' . $cfg['Server']['host'];
+               .  '- ' . __('Host:') . ' ' . $cfg['Server']['host'];
         if (! empty($cfg['Server']['port'])) {
              $head .= ':' . $cfg['Server']['port'];
         }
         $head .= $crlf
-            . '- ' . __('Generation Time') . ': '
+            . '- ' . __('Generation Time:') . ' '
             . PMA_Util::localisedDate() . $crlf
-            . '- ' . __('Server version') . ': ' . PMA_MYSQL_STR_VERSION . $crlf
-            . '- ' . __('PHP Version') . ': ' . phpversion() . $crlf
+            . '- ' . __('Server version:') . ' ' . PMA_MYSQL_STR_VERSION . $crlf
+            . '- ' . __('PHP Version:') . ' ' . phpversion() . $crlf
             . '-->' . $crlf . $crlf;
 
         $head .= '<pma_xml_export version="1.0"'
@@ -207,7 +211,7 @@ class ExportXml extends ExportPlugin
 
         if ($export_struct) {
             if (PMA_DRIZZLE) {
-                $result = PMA_DBI_fetch_result(
+                $result = $GLOBALS['dbi']->fetchResult(
                     "SELECT
                         'utf8' AS DEFAULT_CHARACTER_SET_NAME,
                         DEFAULT_COLLATION_NAME
@@ -216,10 +220,10 @@ class ExportXml extends ExportPlugin
                     . PMA_Util::sqlAddSlashes($db) . "'"
                 );
             } else {
-                $result = PMA_DBI_fetch_result(
+                $result = $GLOBALS['dbi']->fetchResult(
                     'SELECT `DEFAULT_CHARACTER_SET_NAME`, `DEFAULT_COLLATION_NAME`'
                     . ' FROM `information_schema`.`SCHEMATA` WHERE `SCHEMA_NAME`'
-                    . ' = \''.PMA_Util::sqlAddSlashes($db).'\' LIMIT 1'
+                    . ' = \'' . PMA_Util::sqlAddSlashes($db) . '\' LIMIT 1'
                 );
             }
             $db_collation = $result[0]['DEFAULT_COLLATION_NAME'];
@@ -239,7 +243,7 @@ class ExportXml extends ExportPlugin
 
             foreach ($tables as $table) {
                 // Export tables and views
-                $result = PMA_DBI_fetch_result(
+                $result = $GLOBALS['dbi']->fetchResult(
                     'SHOW CREATE TABLE ' . PMA_Util::backquote($db) . '.'
                     . PMA_Util::backquote($table),
                     0
@@ -275,7 +279,7 @@ class ExportXml extends ExportPlugin
                     && $GLOBALS['xml_export_triggers']
                 ) {
                     // Export triggers
-                    $triggers = PMA_DBI_get_triggers($db, $table);
+                    $triggers = $GLOBALS['dbi']->getTriggers($db, $table);
                     if ($triggers) {
                         foreach ($triggers as $trigger) {
                             $code = $trigger['create'];
@@ -301,14 +305,18 @@ class ExportXml extends ExportPlugin
                 && $GLOBALS['xml_export_functions']
             ) {
                 // Export functions
-                $functions = PMA_DBI_get_procedures_or_functions($db, 'FUNCTION');
+                $functions = $GLOBALS['dbi']->getProceduresOrFunctions(
+                    $db, 'FUNCTION'
+                );
                 if ($functions) {
                     foreach ($functions as $function) {
                         $head .= '            <pma:function name="'
                             . $function . '">' . $crlf;
 
                         // Do some formatting
-                        $sql = PMA_DBI_get_definition($db, 'FUNCTION', $function);
+                        $sql = $GLOBALS['dbi']->getDefinition(
+                            $db, 'FUNCTION', $function
+                        );
                         $sql = rtrim($sql);
                         $sql = "                " . htmlspecialchars($sql);
                         $sql = str_replace("\n", "\n                ", $sql);
@@ -326,14 +334,18 @@ class ExportXml extends ExportPlugin
                 && $GLOBALS['xml_export_procedures']
             ) {
                 // Export procedures
-                $procedures = PMA_DBI_get_procedures_or_functions($db, 'PROCEDURE');
+                $procedures = $GLOBALS['dbi']->getProceduresOrFunctions(
+                    $db, 'PROCEDURE'
+                );
                 if ($procedures) {
                     foreach ($procedures as $procedure) {
                         $head .= '            <pma:procedure name="'
                             . $procedure . '">' . $crlf;
 
                         // Do some formatting
-                        $sql = PMA_DBI_get_definition($db, 'PROCEDURE', $procedure);
+                        $sql = $GLOBALS['dbi']->getDefinition(
+                            $db, 'PROCEDURE', $procedure
+                        );
                         $sql = rtrim($sql);
                         $sql = "                " . htmlspecialchars($sql);
                         $sql = str_replace("\n", "\n                ", $sql);
@@ -347,6 +359,37 @@ class ExportXml extends ExportPlugin
                 }
             }
 
+            if (isset($GLOBALS['xml_export_events'])
+                && $GLOBALS['xml_export_events']
+            ) {
+                if (PMA_MYSQL_INT_VERSION > 50100) {
+                    // Export events
+                    $events = $GLOBALS['dbi']->fetchResult(
+                        "SELECT EVENT_NAME FROM information_schema.EVENTS "
+                        . "WHERE EVENT_SCHEMA='" . PMA_Util::sqlAddslashes($db) . "'"
+                    );
+                    if ($events) {
+                        foreach ($events as $event) {
+                            $head .= '            <pma:event name="'
+                                . $event . '">' . $crlf;
+
+                            $sql = $GLOBALS['dbi']->getDefinition(
+                                $db, 'EVENT', $event
+                            );
+                            $sql = rtrim($sql);
+                            $sql = "                " . htmlspecialchars($sql);
+                            $sql = str_replace("\n", "\n                ", $sql);
+
+                            $head .= $sql . $crlf;
+                            $head .= '            </pma:event>' . $crlf;
+                        }
+
+                        unset($event);
+                        unset($events);
+                    }
+                }
+            }
+
             unset($result);
 
             $head .= '        </pma:database>' . $crlf;
@@ -387,7 +430,7 @@ class ExportXml extends ExportPlugin
             && $GLOBALS['xml_export_contents']
         ) {
             $head = '    <!--' . $crlf
-                  . '    - ' . __('Database') . ': ' .  '\'' . $db . '\'' . $crlf
+                  . '    - ' . __('Database:') . ' ' .  '\'' . $db . '\'' . $crlf
                   . '    -->' . $crlf
                   . '    <database name="' . htmlspecialchars($db) . '">' . $crlf;
 
@@ -445,12 +488,14 @@ class ExportXml extends ExportPlugin
         if (isset($GLOBALS['xml_export_contents'])
             && $GLOBALS['xml_export_contents']
         ) {
-            $result = PMA_DBI_query($sql_query, null, PMA_DBI_QUERY_UNBUFFERED);
+            $result = $GLOBALS['dbi']->query(
+                $sql_query, null, PMA_DatabaseInterface::QUERY_UNBUFFERED
+            );
 
-            $columns_cnt = PMA_DBI_num_fields($result);
+            $columns_cnt = $GLOBALS['dbi']->numFields($result);
             $columns = array();
             for ($i = 0; $i < $columns_cnt; $i++) {
-                $columns[$i] = stripslashes(PMA_DBI_field_name($result, $i));
+                $columns[$i] = stripslashes($GLOBALS['dbi']->fieldName($result, $i));
             }
             unset($i);
 
@@ -459,7 +504,7 @@ class ExportXml extends ExportPlugin
                 return false;
             }
 
-            while ($record = PMA_DBI_fetch_row($result)) {
+            while ($record = $GLOBALS['dbi']->fetchRow($result)) {
                 $buffer = '        <table name="'
                     . htmlspecialchars($table) . '">' . $crlf;
                 for ($i = 0; $i < $columns_cnt; $i++) {
@@ -479,7 +524,7 @@ class ExportXml extends ExportPlugin
                     return false;
                 }
             }
-            PMA_DBI_free_result($result);
+            $GLOBALS['dbi']->freeResult($result);
         }
 
         return true;
@@ -492,7 +537,7 @@ class ExportXml extends ExportPlugin
     /**
      * Gets the table name
      *
-     * @return void
+     * @return string
      */
     private function _getTable()
     {
