@@ -9,6 +9,8 @@ if (! defined('PHPMYADMIN')) {
     exit;
 }
 
+require_once 'libraries/schema/Export_Relation_Schema.class.php';
+
 /**
  * This Class interacts with the user to gather the information
  * about their tables for which they want to export the relational schema
@@ -123,48 +125,53 @@ class PMA_User_Schema
      */
     public function showCreatePageDialog($db)
     {
-        ?>
-        <form method="post" action="schema_edit.php" name="frm_create_page">
-        <fieldset>
-        <legend>
-        <?php echo __('Create a page') . "\n"; ?>
-        </legend>
-        <?php echo PMA_generate_common_hidden_inputs($db); ?>
-        <input type="hidden" name="do" value="createpage" />
-        <table>
-        <tr>
-        <td><label for="id_newpage"><?php echo __('Page name'); ?></label></td>
-        <td>
-        <input type="text" name="newpage" id="id_newpage" size="20" maxlength="50" />
-        </td>
-        </tr>
-        <tr>
-        <td><?php echo __('Automatic layout based on'); ?></td>
-        <td>
-        <input type="checkbox" name="auto_layout_internal" id="id_auto_layout_internal" /><label for="id_auto_layout_internal">
-        <?php echo __('Internal relations'); ?></label><br />
-        <?php
+        $htmlString = '<form method="post" action="schema_edit.php"'
+            . ' name="frm_create_page">'
+            . '<fieldset>'
+            . '<legend>'
+            .  __('Create a page')
+            . '</legend>'
+            . PMA_URL_getHiddenInputs($db)
+            . '<input type="hidden" name="do" value="createpage" />'
+            . '<table>'
+            . '<tr>'
+            . '<td><label for="id_newpage">' . __('Page name') . '</label></td>'
+            . '<td>'
+            . '<input type="text" name="newpage" id="id_newpage"'
+            . ' size="20" maxlength="50" />'
+            . '</td>'
+            . '</tr>'
+            . '<tr>'
+            . __('Automatic layout based on') . '</td>'
+            . '<td>'
+            . '<input type="checkbox" name="auto_layout_internal"'
+            . ' id="id_auto_layout_internal" /><label for="id_auto_layout_internal">'
+            . __('Internal relations') . '</label><br />';
+
         /*
          * Check to see whether INNODB and PBXT storage engines
          * are Available in MYSQL PACKAGE
          * If available, then provide AutoLayout for Foreign Keys in Schema View
          */
 
-        if (PMA_StorageEngine::isValid('InnoDB') || PMA_StorageEngine::isValid('PBXT')) {
-            ?>
-            <input type="checkbox" name="auto_layout_foreign" id="id_auto_layout_foreign" /><label for="id_auto_layout_foreign">
-            <?php echo __('FOREIGN KEY'); ?></label><br />
-            <?php
+        if (PMA_StorageEngine::isValid('InnoDB')
+            || PMA_StorageEngine::isValid('PBXT')
+        ) {
+            $htmlString .= '<input type="checkbox" name="auto_layout_foreign"'
+                . ' id="id_auto_layout_foreign" />'
+                . '<label for="id_auto_layout_foreign">'
+                .  __('FOREIGN KEY') . '</label><br />';
         }
-        ?>
-        </td></tr>
-        </table>
-        </fieldset>
-        <fieldset class="tblFooters">
-        <input type="submit" value="<?php echo __('Go'); ?>" />
-        </fieldset>
-        </form>
-        <?php
+
+        $htmlString .= '</td></tr>'
+            . '</table>'
+            . '</fieldset>'
+            . '<fieldset class="tblFooters">'
+            . '<input type="submit" value="' . __('Go') . '" />'
+            . '</fieldset>'
+            . '</form>';
+
+        echo $htmlString;
     }
 
     /**
@@ -182,22 +189,22 @@ class PMA_User_Schema
             . PMA_Util::backquote($cfgRelation['pdf_pages'])
             . ' WHERE db_name = \'' . PMA_Util::sqlAddSlashes($db) . '\'';
         $page_rs    = PMA_queryAsControlUser(
-            $page_query, false, PMA_DBI_QUERY_STORE
+            $page_query, false, PMA_DatabaseInterface::QUERY_STORE
         );
 
-        if ($page_rs && PMA_DBI_num_rows($page_rs) > 0) {
+        if ($page_rs && $GLOBALS['dbi']->numRows($page_rs) > 0) {
             ?>
             <form method="get" action="schema_edit.php" name="frm_select_page">
             <fieldset>
             <legend>
             <?php echo __('Please choose a page to edit') . "\n"; ?>
             </legend>
-            <?php echo PMA_generate_common_hidden_inputs($db, $table); ?>
+            <?php echo PMA_URL_getHiddenInputs($db, $table); ?>
             <input type="hidden" name="do" value="selectpage" />
             <select name="chpage" id="chpage" class="autosubmit">
             <option value="0"><?php echo __('Select page'); ?></option>
             <?php
-            while ($curr_page = PMA_DBI_fetch_assoc($page_rs)) {
+            while ($curr_page = $GLOBALS['dbi']->fetchAssoc($page_rs)) {
                 echo "\n" . '        '
                     . '<option value="' . $curr_page['page_nr'] . '"';
                 if (isset($this->chosenPage)
@@ -245,12 +252,12 @@ class PMA_User_Schema
          * We will need an array of all tables in this db
          */
         $selectboxall = array('--');
-        $alltab_rs    = PMA_DBI_query(
+        $alltab_rs    = $GLOBALS['dbi']->query(
             'SHOW TABLES FROM ' . PMA_Util::backquote($db) . ';',
             null,
-            PMA_DBI_QUERY_STORE
+            PMA_DatabaseInterface::QUERY_STORE
         );
-        while ($val = @PMA_DBI_fetch_row($alltab_rs)) {
+        while ($val = @$GLOBALS['dbi']->fetchRow($alltab_rs)) {
                $selectboxall[] = $val[0];
         }
 
@@ -271,7 +278,7 @@ class PMA_User_Schema
                 . PMA_Util::sqlAddSlashes($this->chosenPage) . '\'';
             $page_rs    = PMA_queryAsControlUser($page_query, false);
             $array_sh_page = array();
-            while ($temp_sh_page = @PMA_DBI_fetch_assoc($page_rs)) {
+            while ($temp_sh_page = @$GLOBALS['dbi']->fetchAssoc($page_rs)) {
                    $array_sh_page[] = $temp_sh_page;
             }
             /*
@@ -289,7 +296,7 @@ class PMA_User_Schema
 
             echo '<form method="post" action="schema_edit.php" name="edcoord">';
 
-            echo PMA_generate_common_hidden_inputs($db, $table);
+            echo PMA_URL_getHiddenInputs($db, $table);
             echo '<input type="hidden" name="chpage" '
                 . 'value="' . htmlspecialchars($this->chosenPage) . '" />';
             echo '<input type="hidden" name="do" value="edcoord" />';
@@ -329,7 +336,7 @@ class PMA_User_Schema
                     echo 'even';
                 }
                 echo '">';
-                $odd_row = !$odd_row;
+                $odd_row = ! $odd_row;
 
                 echo '<td>';
                 echo '<select name="c_table_' . $i . '[name]">';
@@ -346,9 +353,9 @@ class PMA_User_Schema
                 echo '</td>';
 
                 echo '<td>';
-                echo '<input type="checkbox" id="id_c_table_' . $i .'" '
+                echo '<input type="checkbox" id="id_c_table_' . $i . '" '
                     . 'name="c_table_' . $i . '[delete]" value="y" />';
-                echo '<label for="id_c_table_' . $i .'">'
+                echo '<label for="id_c_table_' . $i . '">'
                     . __('Delete') . '</label>';
                 echo '</td>';
 
@@ -377,7 +384,7 @@ class PMA_User_Schema
                 . '" />';
             echo '<input type="checkbox" id="id_with_field_names" '
                 . 'name="with_field_names" '
-                . (isset($with_field_names) ? 'checked="checked"' : ''). ' />';
+                . (isset($with_field_names) ? 'checked="checked"' : '') . ' />';
             echo '<label for="id_with_field_names">'
                 . __('Column names') . '</label><br />';
             echo '<input type="submit" value="' . __('Save') . '" />';
@@ -400,94 +407,103 @@ class PMA_User_Schema
 
     public function displaySchemaGenerationOptions()
     {
-        global $cfg,$db,$test_rs,$chpage;
-        ?>
-        <form method="post" action="schema_export.php" class="disableAjax">
-            <fieldset>
-            <legend>
-            <?php
-            echo PMA_generate_common_hidden_inputs($db);
-            if (in_array(
-                    $GLOBALS['cfg']['ActionLinksMode'],
-                    array('icons', 'both')
-                )
-            ) {
-                echo PMA_Util::getImage('b_views.png');
+        global $cfg, $db, $test_rs, $chpage;
+
+        $htmlString = '<form method="post" action="schema_export.php"'
+            . ' class="disableAjax">'
+            . '<fieldset>'
+            . '<legend>'
+            . PMA_URL_getHiddenInputs($db);
+
+        if (PMA_Util::showIcons('ActionLinksMode')) {
+            $htmlString .= PMA_Util::getImage('b_views.png');
+        }
+
+        /*
+         * TODO: This list should be generated dynamically based on list of
+         * available plugins.
+         */
+        $htmlString .= __('Display relational schema')
+            . ':'
+            . '</legend>'
+            . '<select name="export_type" id="export_type">';
+        if (file_exists(TCPDF_INC)) {
+            $htmlString .= '<option value="pdf" selected="selected">PDF</option>';
+        }
+        $htmlString .=
+            '<option value="svg">SVG</option>'
+            . '<option value="dia">DIA</option>'
+            . '<option value="eps">EPS</option>'
+            . '</select>'
+            . '<label>' . __('Select Export Relational Type') . '</label><br />';
+        if (isset($test_rs)) {
+            $htmlString .= '<label for="pdf_page_number_opt">'
+                . __('Page number:')
+                . '</label>'
+                . '<select name="pdf_page_number" id="pdf_page_number_opt">';
+
+            while ($pages = @$GLOBALS['dbi']->fetchAssoc($test_rs)) {
+                $htmlString .= '<option value="' . $pages['page_nr'] . '">'
+                    . $pages['page_nr'] . ': '
+                    . htmlspecialchars($pages['page_descr'])
+                    . '</option>' . "\n";
+            } // end while
+            $GLOBALS['dbi']->freeResult($test_rs);
+            unset($test_rs);
+
+            $htmlString .= '</select><br />';
+        } else {
+            $htmlString .= '<input type="hidden" name="pdf_page_number"'
+                . ' value="' . htmlspecialchars($this->chosenPage) . '" />';
+        }
+        $htmlString .= '<input type="hidden" name="do" value="process_export" />'
+            . '<input type="hidden" name="chpage" value="' . $chpage . '" />'
+            . '<input type="checkbox" name="show_grid" id="show_grid_opt" />'
+            . '<label for="show_grid_opt">' . __('Show grid') . '</label><br />'
+            . '<input type="checkbox" name="show_color"'
+            . ' id="show_color_opt" checked="checked" />'
+            . '<label for="show_color_opt">' . __('Show color') . '</label>'
+            . '<br />'
+            . '<input type="checkbox" name="show_table_dimension"'
+            . ' id="show_table_dim_opt" />'
+            . '<label for="show_table_dim_opt">'
+            . __('Show dimension of tables')
+            . '</label><br />'
+            . '<input type="checkbox" name="all_tables_same_width"'
+            . ' id="all_tables_same_width" />'
+            . '<label for="all_tables_same_width">'
+            . __('Same width for all tables')
+            . '</label><br />'
+            . '<input type="checkbox" name="with_doc"'
+            . ' id="with_doc" checked="checked" />'
+            . '<label for="with_doc">' . __('Data Dictionary') . '</label><br />'
+            . '<input type="checkbox" name="show_keys" id="show_keys" />'
+            . '<label for="show_keys">' . __('Only show keys') . '</label><br />'
+            . '<select name="orientation" id="orientation_opt" class="paper-change">'
+            . '<option value="L">' . __('Landscape') . '</option>'
+            . '<option value="P">' . __('Portrait') . '</option>'
+            . '</select>'
+            . '<label for="orientation_opt">' . __('Orientation') . '</label>'
+            . '<br />'
+            . '<select name="paper" id="paper_opt" class="paper-change">';
+
+        foreach ($cfg['PDFPageSizes'] as $val) {
+            $htmlString .= '<option value="' . $val . '"';
+            if ($val == $cfg['PDFDefaultPageSize']) {
+                $htmlString .= ' selected="selected"';
             }
-            echo __('Display relational schema');
-            ?>:
-            </legend>
-            <select name="export_type" id="export_type">
-                <option value="pdf" selected="selected">PDF</option>
-                <option value="svg">SVG</option>
-                <option value="dia">DIA</option>
-                <option value="eps">EPS</option>
-            </select>
-            <label><?php echo __('Select Export Relational Type');?></label><br />
-            <?php
-            if (isset($test_rs)) {
-            ?>
-            <label for="pdf_page_number_opt"><?php echo __('Page number:'); ?></label>
-            <select name="pdf_page_number" id="pdf_page_number_opt">
-                <?php
-                while ($pages = @PMA_DBI_fetch_assoc($test_rs)) {
-                    echo '                <option value="' . $pages['page_nr'] . '">'
-                        . $pages['page_nr'] . ': ' . htmlspecialchars($pages['page_descr']) . '</option>' . "\n";
-                } // end while
-                PMA_DBI_free_result($test_rs);
-                unset($test_rs);
-                ?>
-            </select><br />
-            <?php
-            } else {
-            ?>
-            <input type="hidden" name="pdf_page_number" value="<?php echo htmlspecialchars($this->chosenPage); ?>" />
-            <?php
-            }
-            ?>
-            <input type="hidden" name="do" value="process_export" />
-            <input type="hidden" name="chpage" value="<?php echo $chpage; ?>" />
-            <input type="checkbox" name="show_grid" id="show_grid_opt" />
-            <label for="show_grid_opt"><?php echo __('Show grid'); ?></label><br />
-            <input type="checkbox" name="show_color" id="show_color_opt" checked="checked" />
-            <label for="show_color_opt"><?php echo __('Show color'); ?></label>
-            <br />
-            <input type="checkbox" name="show_table_dimension" id="show_table_dim_opt" />
-            <label for="show_table_dim_opt">
-            <?php echo __('Show dimension of tables'); ?>
-            </label><br />
-            <input type="checkbox" name="all_tables_same_width" id="all_tables_same_width" />
-            <label for="all_tables_same_width">
-            <?php echo __('Display all tables with the same width'); ?>
-            </label><br />
-            <input type="checkbox" name="with_doc" id="with_doc" checked="checked" />
-            <label for="with_doc"><?php echo __('Data Dictionary'); ?></label><br />
-            <input type="checkbox" name="show_keys" id="show_keys" />
-            <label for="show_keys"><?php echo __('Only show keys'); ?></label><br />
-            <select name="orientation" id="orientation_opt" class="paper-change">
-                <option value="L"><?php echo __('Landscape');?></option>
-                <option value="P"><?php echo __('Portrait');?></option>
-            </select>
-            <label for="orientation_opt"><?php echo __('Orientation'); ?></label>
-            <br />
-            <select name="paper" id="paper_opt" class="paper-change">
-                <?php
-                foreach ($cfg['PDFPageSizes'] as $val) {
-                        echo '<option value="' . $val . '"';
-                        if ($val == $cfg['PDFDefaultPageSize']) {
-                            echo ' selected="selected"';
-                        }
-                        echo ' >' . $val . '</option>' . "\n";
-                }
-                ?>
-            </select>
-            <label for="paper_opt"><?php echo __('Paper size'); ?></label>
-            </fieldset>
-            <fieldset class="tblFooters">
-            <input type="submit" value="<?php echo __('Go'); ?>" />
-            </fieldset>
-        </form>
-        <?php
+            $htmlString .= ' >' . $val . '</option>' . "\n";
+        }
+
+        $htmlString .= '</select>'
+            . '<label for="paper_opt">' . __('Paper size') . '</label>'
+            . '</fieldset>'
+            . '<fieldset class="tblFooters">'
+            . '<input type="submit" value="' .  __('Go') . '" />'
+            . '</fieldset>'
+            . '</form>';
+
+        echo $htmlString;
     }
 
     /**
@@ -517,11 +533,11 @@ class PMA_User_Schema
                 $shoot       = true;
             }
         }
-        if (!$shoot) {
+        if (! $shoot) {
             return;
         }
         echo '<br /><form action="schema_edit.php" method="post">' . "\n"
-            . PMA_generate_common_hidden_inputs($db)
+            . PMA_URL_getHiddenInputs($db)
             . '<input type="hidden" name="do" value="delete_old_references" />'
             . "\n"
             . '<input type="hidden" name="chpage" value="'
@@ -566,7 +582,7 @@ class PMA_User_Schema
             $drag_y = $temp_sh_page['y'];
 
             echo '<div id="table_' . $i . '" '
-                . 'data-number="' . $i .'" '
+                . 'data-number="' . $i . '" '
                 . 'data-x="' . $drag_x . '" '
                 . 'data-y="' . $drag_y . '" '
                 . 'class="pdflayout_table"'
@@ -576,7 +592,9 @@ class PMA_User_Schema
                 . '</u>';
 
             if (isset($with_field_names)) {
-                $fields = PMA_DBI_get_columns($db, $temp_sh_page['table_name']);
+                $fields = $GLOBALS['dbi']->getColumns(
+                    $db, $temp_sh_page['table_name']
+                );
                 // if the table has been dropped from outside phpMyAdmin,
                 // we can no longer obtain its columns list
                 if ($fields) {
@@ -637,15 +655,33 @@ class PMA_User_Schema
          * default is PDF, otherwise validate it's only letters a-z
          */
         global  $db,$export_type;
-        if (!isset($export_type) || !preg_match('/^[a-zA-Z]+$/', $export_type)) {
+
+        if (! isset($export_type) || ! preg_match('/^[a-zA-Z]+$/', $export_type)) {
             $export_type = 'pdf';
         }
+        $GLOBALS['dbi']->selectDb($db);
 
-        PMA_DBI_select_db($db);
-
-        include "libraries/schema/" . ucfirst($export_type)
-            . "_Relation_Schema.class.php";
-        eval("new PMA_" . ucfirst($export_type) . "_Relation_Schema();");
+        $path = PMA_securePath(ucfirst($export_type));
+        $filename = 'libraries/schema/' . $path . '_Relation_Schema.class.php';
+        if (!file_exists($filename)) {
+            PMA_Export_Relation_Schema::dieSchema(
+                $_POST['chpage'],
+                $export_type,
+                __('File doesn\'t exist')
+            );
+        }
+        $GLOBALS['skip_import'] = false;
+        include $filename;
+        if ( $GLOBALS['skip_import']) {
+            PMA_Export_Relation_Schema::dieSchema(
+                $_POST['chpage'],
+                $export_type,
+                __('Plugin is disabled')
+            );
+        }
+        $class_name = 'PMA_' . $path . '_Relation_Schema';
+        $obj_schema = new $class_name();
+        $obj_schema->showOutput();
     }
 
     /**
@@ -719,7 +755,7 @@ class PMA_User_Schema
              * and PBXT tables, as this logic is just to put
              * the tables on the layout, not to determine relations
              */
-            $tables = PMA_DBI_get_tables_full($db);
+            $tables = $GLOBALS['dbi']->getTablesFull($db);
             $foreignkey_tables = array();
             foreach ($tables as $table_name => $table_properties) {
                 if (PMA_Util::isForeignKeySupported($table_properties['ENGINE'])) {
@@ -748,14 +784,18 @@ class PMA_User_Schema
                 . ' GROUP BY master_table'
                 . ' ORDER BY COUNT(master_table) DESC';
             $master_tables_rs = PMA_queryAsControlUser(
-                $master_tables, false, PMA_DBI_QUERY_STORE
+                $master_tables, false, PMA_DatabaseInterface::QUERY_STORE
             );
-            if ($master_tables_rs && PMA_DBI_num_rows($master_tables_rs) > 0) {
+            if ($master_tables_rs
+                && $GLOBALS['dbi']->numRows($master_tables_rs) > 0
+            ) {
                 /* first put all the master tables at beginning
                  * of the list, so they are near the center of
                  * the schema
                  */
-                while (list(, $master_table) = PMA_DBI_fetch_row($master_tables_rs)) {
+                while (list(, $master_table)
+                    = $GLOBALS['dbi']->fetchRow($master_tables_rs)
+                ) {
                        $all_tables[] = $master_table;
                 }
 
@@ -769,7 +809,9 @@ class PMA_User_Schema
                 foreach ($all_tables as $master_table) {
                     $foreigners = PMA_getForeigners($db, $master_table);
                     foreach ($foreigners as $foreigner) {
-                        if (! in_array($foreigner['foreign_table'], $foreign_tables)) {
+                        if (! in_array(
+                            $foreigner['foreign_table'], $foreign_tables
+                        )) {
                             $foreign_tables[] = $foreigner['foreign_table'];
                         }
                     }
@@ -889,10 +931,10 @@ class PMA_User_Schema
                     . ' AND   pdf_page_number = \''
                     . PMA_Util::sqlAddSlashes($this->chosenPage) . '\'';
                 $test_rs = PMA_queryAsControlUser(
-                    $test_query, false, PMA_DBI_QUERY_STORE
+                    $test_query, false, PMA_DatabaseInterface::QUERY_STORE
                 );
                 //echo $test_query;
-                if ($test_rs && PMA_DBI_num_rows($test_rs) > 0) {
+                if ($test_rs && $GLOBALS['dbi']->numRows($test_rs) > 0) {
                     if (isset($arrvalue['delete']) && $arrvalue['delete'] == 'y') {
                         $ch_query = 'DELETE FROM '
                             . PMA_Util::backquote($GLOBALS['cfgRelation']['db'])
