@@ -1294,15 +1294,6 @@ function PMA_executeQueryAndStoreResults($full_sql_query)
 
     $GLOBALS['querytime'] = $querytime_after - $querytime_before;
 
-    // If a stored procedure was called, there may be more results that are
-    // queued up and waiting to be flushed from the buffer. So let's do that.
-    do {
-        $GLOBALS['dbi']->storeResult();
-        if (! $GLOBALS['dbi']->moreResults()) {
-            break;
-        }
-    } while ($GLOBALS['dbi']->nextResult());
-
     return $result;
 }
 
@@ -1428,7 +1419,7 @@ function PMA_countQueryResults(
                 false
             );
             /**
-             * @todo Can we know at this point that this is InnoDB, 
+             * @todo Can we know at this point that this is InnoDB,
              *       (in this case there would be no need for getting
              *       an exact count)?
              */
@@ -1437,7 +1428,7 @@ function PMA_countQueryResults(
                 // is less than MaxExactCount
                 /**
                  * @todo In countRecords(), MaxExactCount is also verified,
-                 *       so can we avoid checking it twice? 
+                 *       so can we avoid checking it twice?
                  */
                 $unlim_num_rows = PMA_Table::countRecords(
                     $db,
@@ -1880,15 +1871,61 @@ function PMA_getHtmlForSqlQueryResultsTable($sql_data, $displayResultsObject, $d
     $analyzed_sql_results
 ) {
     $printview = isset($_REQUEST['printview']) ? $_REQUEST['printview'] : null;
-    if (! empty($sql_data) && ($sql_data['valid_queries'] > 1)
-        || $analyzed_sql_results['is_procedure']
-    ) {
+    $table_html = '';
+    if (! empty($sql_data) && ($sql_data['valid_queries'] > 1)) {
         $_SESSION['is_multi_query'] = true;
-        $table_html = PMA_getTableHtmlForMultipleQueries(
+        $table_html .= PMA_getTableHtmlForMultipleQueries(
             $displayResultsObject, $db, $sql_data, $goto,
             $pmaThemeImage, $printview, $url_query,
             $disp_mode, $sql_limit_to_append, $editable
         );
+    } elseif ($analyzed_sql_results['is_procedure']) {
+
+        do {
+            if (! isset($result)) {
+                $result = $GLOBALS['dbi']->storeResult();
+            }
+            $num_rows = $GLOBALS['dbi']->numRows($result);
+
+            if ($result !== false && $num_rows > 0) {
+
+                $fields_meta = $GLOBALS['dbi']->getFieldsMeta($result);
+                $fields_cnt  = count($fields_meta);
+
+                $displayResultsObject->setProperties(
+                    $num_rows,
+                    $fields_meta,
+                    $analyzed_sql_results['is_count'],
+                    $analyzed_sql_results['is_export'],
+                    $analyzed_sql_results['is_func'],
+                    $analyzed_sql_results['is_analyse'],
+                    $num_rows,
+                    $fields_cnt,
+                    $GLOBALS['querytime'],
+                    $pmaThemeImage,
+                    $GLOBALS['text_dir'],
+                    $analyzed_sql_results['is_maint'],
+                    $analyzed_sql_results['is_explain'],
+                    $analyzed_sql_results['is_show'],
+                    $showtable,
+                    $printview,
+                    $url_query,
+                    $editable
+                );
+
+                $disp_mode = 'nnnn110111'; // uneditable
+                $table_html .= $displayResultsObject->getTable(
+                    $result,
+                    $disp_mode,
+                    $analyzed_sql_results['analyzed_sql']
+                );
+            }
+
+            $GLOBALS['dbi']->freeResult($result);
+            unset($result);
+
+        } while ($GLOBALS['dbi']->moreResults() && $GLOBALS['dbi']->nextResult());
+
     } else {
         if (isset($result) && $result) {
             $fields_meta = $GLOBALS['dbi']->getFieldsMeta($result);
@@ -1905,7 +1942,7 @@ function PMA_getHtmlForSqlQueryResultsTable($sql_data, $displayResultsObject, $d
             $editable
         );
 
-        $table_html = $displayResultsObject->getTable(
+        $table_html .= $displayResultsObject->getTable(
             $result, $disp_mode, $analyzed_sql_results['analyzed_sql']
         );
         $GLOBALS['dbi']->freeResult($result);
@@ -2406,9 +2443,9 @@ function PMA_getStartPosToDisplayRow($number_of_line, $max_rows = null)
  * Function to calculate new pos if pos is higher than number of rows
  * of displayed table
  *
- * @param String $db    Database name
- * @param String $table Table name
- * @param Int    $pos   Initial position
+ * @param String   $db    Database name
+ * @param String   $table Table name
+ * @param Int|null $pos   Initial position
  *
  * @return Int Number of pos to display last page
  */
