@@ -12,31 +12,17 @@
 require_once 'libraries/common.inc.php';
 require_once 'libraries/pmd_common.php';
 
-/**
- * Sets globals from $_GET
- */
-$get_params = array(
-    'db',
-    'table',
-    'token'
-);
-foreach ($get_params as $one_get_param) {
-    if (isset($_GET[$one_get_param])) {
-        $GLOBALS[$one_get_param] = $_GET[$one_get_param];
-    }
-}
-
-$script_display_field = get_tables_info();
-$tab_column       = get_columns_info();
-$script_tables    = get_script_tabs();
-$script_contr     = get_script_contr();
-$tab_pos          = get_tab_pos();
-$tables_pk_or_unique_keys = get_pk_or_unique_keys();
-$tables_all_keys  = get_all_keys();
+$script_display_field = PMA_getTablesInfo();
+$tab_column       = PMA_getColumnsInfo();
+$script_tables    = PMA_getScriptTabs();
+$script_contr     = PMA_getScriptContr();
+$tab_pos          = PMA_getTabPos();
+$tables_pk_or_unique_keys = PMA_getPKOrUniqueKeys();
+$tables_all_keys  = PMA_getAllKeys();
 
 $params = array('lang' => $GLOBALS['lang']);
-if (isset($GLOBALS['db'])) {
-    $params['db'] = $GLOBALS['db'];
+if (isset($_GET['db'])) {
+    $params['db'] = $_GET['db'];
 }
 
 $response = PMA_Response::getInstance();
@@ -44,12 +30,12 @@ $response->getFooter()->setMinimal();
 $header   = $response->getHeader();
 $header->setBodyId('pmd_body');
 $scripts = $header->getScripts();
+$scripts->addFile('jquery/jquery.fullscreen.js');
 $scripts->addFile('pmd/ajax.js');
 $scripts->addFile('pmd/history.js');
 $scripts->addFile('pmd/move.js');
 $scripts->addFile('pmd/iecanvas.js', true);
 $scripts->addFile('pmd/init.js');
-$scripts->addFile('jquery/jquery.fullscreen.js');
 
 require 'libraries/db_common.inc.php';
 require 'libraries/db_info.inc.php';
@@ -60,10 +46,10 @@ echo '<div id="script_server" class="hide">';
 echo htmlspecialchars($GLOBALS['server']);
 echo '</div>';
 echo '<div id="script_db" class="hide">';
-echo htmlspecialchars($GLOBALS['db']);
+echo htmlspecialchars($_GET['db']);
 echo '</div>';
 echo '<div id="script_token" class="hide">';
-echo htmlspecialchars($GLOBALS['token']);
+echo htmlspecialchars($_GET['token']);
 echo '</div>';
 echo '<div id="script_tables" class="hide">';
 echo htmlspecialchars(json_encode($script_tables));
@@ -79,18 +65,23 @@ echo '</div>';
 <div class="pmd_header" id="top_menu">
     <a href="#" onclick="Show_left_menu(document.getElementById('key_Show_left_menu')); return false"
         class="M_butt first" target="_self">
-        <img id='key_Show_left_menu' title="<?php echo __('Show/Hide left menu'); ?>" alt="v"
+        <img id='key_Show_left_menu'
+            title="<?php echo __('Show/Hide left menu'); ?>" alt="v"
             src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/downarrow2_m.png'); ?>" />
     </a>
-    <a href="#" id="enterFullscreen" onclick="Enter_fullscreen(); return false" class="M_butt" target="_self">
+    <a href="#" id="enterFullscreen" onclick="Enter_fullscreen(); return false"
+        class="M_butt" target="_self">
         <img title="<?php echo __('View in fullscreen') ?>" alt=""
             src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/viewInFullscreen.png'); ?>" />
     </a>
-    <a href="#" id="exitFullscreen" onclick="Exit_fullscreen(); return false" class="M_butt hide" target="_self">
+    <a href="#" id="exitFullscreen" onclick="Exit_fullscreen(); return false"
+        class="M_butt hide" target="_self">
         <img title="<?php echo __('Exit fullscreen') ?>" alt=""
             src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/exitFullscreen.png'); ?>" />
     </a>
-    <img class="M_bord" src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/bord.png'); ?>" alt="" />
+    <img class="M_bord"
+        src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/bord.png'); ?>"
+        alt="" />
     <a href="#" onclick="Save2(); return false" class="M_butt" target="_self">
         <img title="<?php echo __('Save position') ?>" alt=""
             src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/save.png'); ?>" />
@@ -100,7 +91,8 @@ echo '</div>';
         <img title="<?php echo __('Create table')?>" alt=""
             src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/table.png'); ?>" />
     </a>
-    <a href="#" onclick="Start_relation(); return false" class="M_butt" id="rel_button" target="_self">
+    <a href="#" onclick="Start_relation(); return false" class="M_butt"
+        id="rel_button" target="_self">
         <img title="<?php echo __('Create relation') ?>" alt=""
             src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/relation.png'); ?>" />
     </a>
@@ -109,21 +101,26 @@ echo '</div>';
         <img title="<?php echo __('Choose column to display') ?>" alt=""
             src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/display_field.png'); ?>" />
     </a>
-    <a href="#" onclick="location.reload(); return false" class="M_butt" target="_self">
+    <a href="#" onclick="location.reload(); return false" class="M_butt"
+        target="_self">
         <img title="<?php echo __('Reload'); ?>" alt=""
             src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/reload.png'); ?>" />
     </a>
-    <a href="<?php echo PMA_Util::getDocuLink('faq', 'faq6-31') ?>" target="documentation" class="M_butt" target="_self">
+    <a href="<?php echo PMA_Util::getDocuLink('faq', 'faq6-31') ?>"
+        target="documentation" class="M_butt" target="_self">
         <img title="<?php echo __('Help'); ?>" alt=""
             src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/help.png'); ?>" />
     </a>
-    <img class="M_bord" src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/bord.png'); ?>" alt="" />
+    <img class="M_bord"
+        src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/bord.png'); ?>"
+        alt="" />
     <a href="#" onclick="Angular_direct(); return false"
         class="M_butt" id="angular_direct_button" target="_self">
         <img title="<?php echo __('Angular links') . ' / ' . __('Direct links'); ?>" alt=""
             src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/ang_direct.png'); ?>" />
     </a>
-    <a href="#" onclick="Grid(); return false" class="M_butt" id="grid_button" target="_self">
+    <a href="#" onclick="Grid(); return false" class="M_butt" id="grid_button"
+        target="_self">
         <img title="<?php echo __('Snap to grid') ?>"
             src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/grid.png'); ?>" alt="" />
     </a>
@@ -133,24 +130,28 @@ echo '</div>';
         <img id='key_SB_all' title="<?php echo __('Small/Big All'); ?>" alt="v"
             src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/downarrow1.png'); ?>" />
     </a>
-    <a href="#" onclick="Small_tab_invert(); return false" class="M_butt" target="_self" >
+    <a href="#" onclick="Small_tab_invert(); return false" class="M_butt"
+        target="_self" >
         <img title="<?php echo __('Toggle small/big'); ?>" alt="key"
             src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/bottom.png'); ?>" />
     </a>
-    <a href="#" onclick="Relation_lines_invert(); return false" class="M_butt" target="_self" >
+    <a href="#" onclick="Relation_lines_invert(); return false"
+        class="M_butt" target="_self" >
         <img title="<?php echo __('Toggle relation lines'); ?>" alt="key"
             src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/toggle_lines.png'); ?>" />
     </a>
     <img class="M_bord" src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/bord.png'); ?>" alt="" />
     <a href="#" onclick="PDF_save(); return false" class="M_butt ajax">
         <img src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/pdf.png'); ?>" alt="key"
-            width="20" height="20" title="<?php echo __('Import/Export coordinates for PDF schema'); ?>" />
+            width="20" height="20" title="<?php echo __('Import/Export coordinates for relational schema'); ?>" />
     </a>
 <?php
 if (isset($_REQUEST['query'])) {
     echo '<a href="#" onclick="build_query(\'SQL Query on Database\', 0)" onmousedown="return false;"
     class="M_butt" target="_self">';
-    echo '<img src="'. $_SESSION['PMA_Theme']->getImgPath('pmd/query_builder.png') . '" alt="key" width="20" height="20" title="';
+    echo '<img src="'
+        . $_SESSION['PMA_Theme']->getImgPath('pmd/query_builder.png')
+        . '" alt="key" width="20" height="20" title="';
     echo __('Build Query');
     echo '"/></a>';
 }
@@ -165,7 +166,8 @@ if (isset($_REQUEST['query'])) {
 <div id="canvas_outer">
 <form action="" method="post" name="form1">
 <div id="osn_tab">
-  <canvas class="pmd" id="canvas" width="100" height="100" onclick="Canvas_click(this)"></canvas>
+  <canvas class="pmd" id="canvas" width="100" height="100"
+          onclick="Canvas_click(this)"></canvas>
 </div>
 <div id="layer_menu" style="display:none;">
 <div class="center" style="padding-top:5px;">
@@ -189,24 +191,29 @@ for ($i = 0; $i < $name_cnt; $i++) {
         . 'onmouseover="this.className=\'L_butt2_2\'" '
         . 'onmouseout="this.className=\'L_butt2_1\'" class="L_butt2_1">';
     echo '<img '
-        . 'onclick="Start_tab_upd(\'' . $GLOBALS['PMD_URL']["TABLE_NAME_SMALL"][$i] . '\');" '
-        . 'src="' . $_SESSION['PMA_Theme']->getImgPath('pmd/exec.png') . '" alt="" />';
+        . 'onclick="Start_tab_upd(\''
+        . $GLOBALS['PMD_URL']["TABLE_NAME_SMALL"][$i] . '\');" '
+        . 'src="' . $_SESSION['PMA_Theme']->getImgPath('pmd/exec.png')
+        . '" alt="" />';
     echo '</td>';
     echo '<td width="1px">';
-    echo '<input onclick="VisibleTab(this,\'' . $GLOBALS['PMD_URL']["TABLE_NAME"][$i] . '\')" '
+    echo '<input onclick="VisibleTab(this,\''
+        . $GLOBALS['PMD_URL']["TABLE_NAME"][$i] . '\')" '
         . 'title="' . __('Hide') . '" '
         . 'id="check_vis_' . $GLOBALS['PMD_URL']["TABLE_NAME"][$i] . '" '
         . 'style="margin:0px;" type="checkbox" '
         . 'value="' . $GLOBALS['PMD_URL']["TABLE_NAME"][$i] . '"';
     if (isset($tab_pos[$GLOBALS['PMD']["TABLE_NAME"][$i]])) {
-        echo $tab_pos[$GLOBALS['PMD']["TABLE_NAME"][$i]]["H"] ? 'checked="checked"' : '';
+        echo $tab_pos[$GLOBALS['PMD']["TABLE_NAME"][$i]]["H"]
+            ? 'checked="checked"'
+            : '';
     } else {
         echo 'checked="checked"';
     }
     echo '/></td>';
     echo '<td class="pmd_Tabs" onmouseover="this.className=\'pmd_Tabs2\'" '
-        . 'onmouseout="this.className=\'pmd_Tabs\'" '
-        . 'onclick="Select_tab(\'' . $GLOBALS['PMD_URL']["TABLE_NAME"][$i] . '\');">';
+        . 'onmouseout="this.className=\'pmd_Tabs\'" ' . 'onclick="Select_tab(\''
+        . $GLOBALS['PMD_URL']["TABLE_NAME"][$i] . '\');">';
     echo $GLOBALS['PMD_OUT']["TABLE_NAME"][$i];
     echo '</td>';
     echo '</tr>';
@@ -215,7 +222,7 @@ echo '</table>';
 echo '</div>';
 
 echo '<div class="center">';
-echo __('Number of tables') . ': ' . $name_cnt;
+echo __('Number of tables:') . ' ' . $name_cnt;
 echo '</div>';
 echo '<div class="floatright">';
 echo '<div id="layer_menu_sizer" onmousedown="layer_menu_cur_click=1">';
@@ -227,14 +234,17 @@ for ($i = 0; $i < count($GLOBALS['PMD']["TABLE_NAME"]); $i++) {
     $t_n = $GLOBALS['PMD']["TABLE_NAME"][$i];
     $t_n_url = $GLOBALS['PMD_URL']["TABLE_NAME"][$i];
 
-    ?>
-<input name="t_x[<?php echo $t_n_url ?>]" type="hidden" id="t_x_<?php echo $t_n_url ?>_" />
-<input name="t_y[<?php echo $t_n_url ?>]" type="hidden" id="t_y_<?php echo $t_n_url ?>_" />
-<input name="t_v[<?php echo $t_n_url ?>]" type="hidden" id="t_v_<?php echo $t_n_url ?>_" />
-<input name="t_h[<?php echo $t_n_url ?>]" type="hidden" id="t_h_<?php echo $t_n_url ?>_" />
-
+    echo '<input name="t_x[' . $t_n_url . ']" type="hidden" id="t_x_'
+        . $t_n_url . '_" />'
+        . '<input name="t_y[' . $t_n_url . ']" type="hidden" id="t_y_'
+        . $t_n_url . '_" />'
+        . '<input name="t_v[' . $t_n_url . ']" type="hidden" id="t_v_'
+        . $t_n_url . '_" />'
+        . '<input name="t_h[' . $t_n_url . ']" type="hidden" id="t_h_'
+        . $t_n_url . '_" />';
+?>
 <table id="<?php echo $t_n_url ?>" cellpadding="0" cellspacing="0" class="pmd_tab"
-   style="position: absolute;
+    style="position: absolute;
           left: <?php
           echo isset($tab_pos[$t_n]) ? $tab_pos[$t_n]["X"] : rand(20, 700); ?>px;
           top: <?php
@@ -249,9 +259,11 @@ for ($i = 0; $i < count($GLOBALS['PMD']["TABLE_NAME"]); $i++) {
     <?php
     if (isset($_REQUEST['query'])) {
         echo '<td class="select_all">';
-        echo '<input type="checkbox" value="select_all_'.htmlspecialchars($t_n_url).'" style="margin: 0px;" ';
-        echo 'id="select_all_'.htmlspecialchars($t_n_url).'" title="select all" ';
-        echo 'onclick="Select_all(\''. htmlspecialchars($t_n_url) .'\',\''.htmlspecialchars($GLOBALS['PMD_OUT']["OWNER"][$i]).'\')"></td>';
+        echo '<input type="checkbox" value="select_all_'
+            . htmlspecialchars($t_n_url) . '" style="margin: 0px;" ';
+        echo 'id="select_all_' . htmlspecialchars($t_n_url) . '" title="select all" ';
+        echo 'onclick="Select_all(\'' . htmlspecialchars($t_n_url) . '\',\''
+            . htmlspecialchars($GLOBALS['PMD_OUT']["OWNER"][$i]) . '\')"></td>';
     }
     ?>
     <td class="small_tab" onmouseover="this.className='small_tab2';"
@@ -271,68 +283,85 @@ for ($i = 0; $i < count($GLOBALS['PMD']["TABLE_NAME"]); $i++) {
         onclick="Start_tab_upd('<?php echo $GLOBALS['PMD_URL']["TABLE_NAME_SMALL"][$i]; ?>');">
         <img src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/exec_small.png'); ?>" alt="" /></td>
     <td id="id_zag_<?php echo $t_n_url ?>" class="tab_zag nowrap"
-        onmousedown="cur_click=document.getElementById('<?php echo $t_n_url ?>');"/
+        onmousedown="cur_click=document.getElementById('<?php echo $t_n_url ?>');"
         onmouseover="Table_onover('<?php echo $t_n_url ?>',0,<?php echo (isset($_REQUEST['query'])? 1 : 0 )?> )"
         onmouseout="Table_onover('<?php echo $t_n_url ?>',1,<?php echo (isset($_REQUEST['query']) ? 1 : 0 )?>)">
         <span class='owner'>
-        <?php
-        echo $GLOBALS['PMD_OUT']["OWNER"][$i];
-        echo '.</span>';
-        echo $GLOBALS['PMD_OUT']["TABLE_NAME_SMALL"][$i];
-        ?></td>
+            <?php echo $GLOBALS['PMD_OUT']["OWNER"][$i]; ?>.
+        </span>
+        <?php echo $GLOBALS['PMD_OUT']["TABLE_NAME_SMALL"][$i]; ?>
+    </td>
     <?php
     if (isset($_REQUEST['query'])) {
-        echo '<td class="tab_zag"  onmouseover="Table_onover(\''.htmlspecialchars($t_n_url).'\',0,1)"  id="id_zag_'.htmlspecialchars($t_n_url).'_2"';
-        echo 'onmousedown="cur_click=document.getElementById(\''.htmlspecialchars($t_n_url).'\');"';
-        echo 'onmouseout="Table_onover(\''.htmlspecialchars($t_n_url).'\',1,1)">';
+        echo '<td class="tab_zag"  onmouseover="Table_onover(\''
+            . htmlspecialchars($t_n_url) . '\',0,1)"  id="id_zag_'
+            . htmlspecialchars($t_n_url) . '_2"';
+        echo 'onmousedown="cur_click=document.getElementById(\''
+            . htmlspecialchars($t_n_url) . '\');"';
+        echo 'onmouseout="Table_onover(\'' . htmlspecialchars($t_n_url) . '\',1,1)">';
     }
     ?>
-</tr>
-</thead>
-<tbody id="id_tbody_<?php echo $t_n_url ?>"
+    </tr>
+    </thead>
+    <tbody id="id_tbody_<?php echo $t_n_url ?>"
     <?php
     if (isset($tab_pos[$t_n]) && empty($tab_pos[$t_n]["V"])) {
         echo 'style="display: none;"';
     }
     echo '>';
-    $display_field = PMA_getDisplayField($db, $GLOBALS['PMD']["TABLE_NAME_SMALL"][$i]);
-    for ($j = 0, $id_cnt = count($tab_column[$t_n]["COLUMN_ID"]); $j < $id_cnt; $j++) {
+    $display_field = PMA_getDisplayField(
+        $_GET['db'],
+        $GLOBALS['PMD']["TABLE_NAME_SMALL"][$i]
+    );
+    for (
+        $j = 0, $id_cnt = count($tab_column[$t_n]["COLUMN_ID"]);
+        $j < $id_cnt;
+        $j++
+    ) {
+        echo '<tr id="id_tr_'
+            . $GLOBALS['PMD_URL']["TABLE_NAME_SMALL"][$i] . '.'
+            . urlencode($tab_column[$t_n]["COLUMN_NAME"][$j]) . '"';
+        if ($display_field == $tab_column[$t_n]["COLUMN_NAME"][$j]) {
+            echo ' class="tab_field_3" ';
+        } else {
+            echo ' class="tab_field" ';
+        }
         ?>
-<tr id="id_tr_<?php
-        echo $GLOBALS['PMD_URL']["TABLE_NAME_SMALL"][$i] . '.'
-            . urlencode($tab_column[$t_n]["COLUMN_NAME"][$j]) ?>"
-        <?php
-    if ($display_field == $tab_column[$t_n]["COLUMN_NAME"][$j]) {
-        echo ' class="tab_field_3" ';
-    } else {
-        echo ' class="tab_field" ';
-    }
-        ?>
-    onmouseover="old_class = this.className; this.className = 'tab_field_2';"
-    onmouseout="this.className = old_class;"
-    onmousedown="Click_field('<?php
-    echo $GLOBALS['PMD_URL']["TABLE_NAME_SMALL"][$i]."','".urlencode($tab_column[$t_n]["COLUMN_NAME"][$j])."',";
-    if (!PMA_Util::isForeignKeySupported($GLOBALS['PMD']['TABLE_TYPE'][$i])) {
-        echo (isset($tables_pk_or_unique_keys[$t_n . "." . $tab_column[$t_n]["COLUMN_NAME"][$j]]) ? 1 : 0);
-    } else {
-        // if foreign keys are supported, it's not necessary that the
-        // index is a primary key
-        echo (isset($tables_all_keys[$t_n.".".$tab_column[$t_n]["COLUMN_NAME"][$j]]) ? 1 : 0);
-    }
+        onmouseover="old_class = this.className; this.className = 'tab_field_2';"
+        onmouseout="this.className = old_class;"
+        onmousedown="Click_field('<?php
+        echo $GLOBALS['PMD_URL']["TABLE_NAME_SMALL"][$i] . "','"
+            . urlencode($tab_column[$t_n]["COLUMN_NAME"][$j]) . "',";
+        $tmpColumn = $t_n . "." . $tab_column[$t_n]["COLUMN_NAME"][$j];
+        if (!PMA_Util::isForeignKeySupported($GLOBALS['PMD']['TABLE_TYPE'][$i])) {
+            echo (isset($tables_pk_or_unique_keys[$tmpColumn]) ? 1 : 0);
+        } else {
+            // if foreign keys are supported, it's not necessary that the
+            // index is a primary key
+            echo (isset($tables_all_keys[$tmpColumn]) ? 1 : 0);
+        }
         ?>)">
     <?php
-    if (isset($_REQUEST['query'])) {
-        echo '<td class="select_all">';
-        echo '<input value="'.htmlspecialchars($t_n_url).urlencode($tab_column[$t_n]["COLUMN_NAME"][$j]).'"';
-        echo 'type="checkbox" id="select_'.htmlspecialchars($t_n_url).'._'.urlencode($tab_column[$t_n]["COLUMN_NAME"][$j]).'" ';
-        echo 'style="margin: 0px;" title="select_'.urlencode($tab_column[$t_n]["COLUMN_NAME"][$j]).'" ';
-        echo 'onclick="store_column(\''.urlencode($GLOBALS['PMD_OUT']["TABLE_NAME_SMALL"][$i]).'\',\''.htmlspecialchars($GLOBALS['PMD_OUT']["OWNER"][$i]).'\',\''.urlencode($tab_column[$t_n]["COLUMN_NAME"][$j]).'\')"></td>';
-    }?>
-    <td width="10px" colspan="3"
-        id="<?php echo $t_n_url.".".urlencode($tab_column[$t_n]["COLUMN_NAME"][$j]) ?>">
+        if (isset($_REQUEST['query'])) {
+            echo '<td class="select_all">';
+            echo '<input value="' . htmlspecialchars($t_n_url)
+            . urlencode($tab_column[$t_n]["COLUMN_NAME"][$j]) . '"';
+            echo 'type="checkbox" id="select_' . htmlspecialchars($t_n_url) . '._'
+            . urlencode($tab_column[$t_n]["COLUMN_NAME"][$j]) . '" ';
+            echo  'style="margin: 0px;" title="select_'
+            . urlencode($tab_column[$t_n]["COLUMN_NAME"][$j]) . '" ';
+            echo 'onclick="store_column(\''
+            . urlencode($GLOBALS['PMD_OUT']["TABLE_NAME_SMALL"][$i]) . '\',\''
+            . htmlspecialchars($GLOBALS['PMD_OUT']["OWNER"][$i]) . '\',\''
+            . urlencode($tab_column[$t_n]["COLUMN_NAME"][$j]) . '\')"></td>';
+        }?>
+        <td width="10px" colspan="3"
+        id="<?php echo $t_n_url
+             . "."
+             . urlencode($tab_column[$t_n]["COLUMN_NAME"][$j]) ?>">
         <div class="nowrap">
         <?php
-        if (isset($tables_pk_or_unique_keys[$t_n.".".$tab_column[$t_n]["COLUMN_NAME"][$j]])) {
+        if (isset($tables_pk_or_unique_keys[$t_n . "." . $tab_column[$t_n]["COLUMN_NAME"][$j]])) {
             ?>
                 <img src="<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>pmd/FieldKey_small.png"
                     alt="*" />
@@ -360,17 +389,20 @@ for ($i = 0; $i < count($GLOBALS['PMD']["TABLE_NAME"]); $i++) {
             <?php
         }
         echo htmlspecialchars(
-            $tab_column[$t_n]["COLUMN_NAME"][$j] . " : " . $tab_column[$t_n]["TYPE"][$j],
+            $tab_column[$t_n]["COLUMN_NAME"][$j] . " : "
+            . $tab_column[$t_n]["TYPE"][$j],
             ENT_QUOTES
         );
         echo "</div>\n</td>\n";
         if (isset($_REQUEST['query'])) {
-            //$temp = $GLOBALS['PMD_OUT']["OWNER"][$i].'.'.$GLOBALS['PMD_OUT']["TABLE_NAME_SMALL"][$i];
-            echo '<td class="small_tab_pref" onmouseover="this.className=\'small_tab_pref2\';"';
+            /*$temp = $GLOBALS['PMD_OUT']["OWNER"][$i] . '.'
+            . $GLOBALS['PMD_OUT']["TABLE_NAME_SMALL"][$i];*/
+            echo '<td class="small_tab_pref" '
+                . 'onmouseover="this.className=\'small_tab_pref2\';"';
             echo 'onmouseout="this.className=\'small_tab_pref\';"';
             echo 'onclick="Click_option(\'pmd_optionse\',\''
                 . urlencode($tab_column[$t_n]["COLUMN_NAME"][$j]) . '\',\''
-                . $GLOBALS['PMD_OUT']["TABLE_NAME_SMALL"][$i].'\')" >';
+                . $GLOBALS['PMD_OUT']["TABLE_NAME_SMALL"][$i] . '\')" >';
             echo  '<img src="'
                 . $_SESSION['PMA_Theme']->getImgPath('pmd/exec_small.png')
                 . '" title="options" alt="" /></td> ';
@@ -398,7 +430,9 @@ for ($i = 0; $i < count($GLOBALS['PMD']["TABLE_NAME"]); $i++) {
         <table width="168" class="center" cellpadding="2" cellspacing="0">
         <thead>
         <tr>
-            <td colspan="2" class="center nowrap"><strong><?php echo __('Create relation'); ?></strong></td>
+            <td colspan="2" class="center nowrap">
+                <strong><?php echo __('Create relation'); ?></strong>
+            </td>
         </tr>
         </thead>
         <tbody id="foreign_relation">
@@ -464,7 +498,9 @@ for ($i = 0; $i < count($GLOBALS['PMD']["TABLE_NAME"]); $i++) {
     <td class="input_tab">
         <table width="100%" class="center" cellpadding="2" cellspacing="0">
         <tr>
-            <td colspan="3" class="center nowrap"><strong><?php echo __('Delete relation'); ?></strong></td>
+            <td colspan="3" class="center nowrap">
+                <strong><?php echo __('Delete relation'); ?></strong>
+            </td>
         </tr>
         <tr>
             <td colspan="3" class="center nowrap">
@@ -500,7 +536,9 @@ for ($i = 0; $i < count($GLOBALS['PMD']["TABLE_NAME"]); $i++) {
         <table width="168" class="center" cellpadding="2" cellspacing="0">
        <thead>
         <tr>
-            <td colspan="2" rowspan="2" id="option_col_name" class="center nowrap"></td>
+            <td colspan="2" rowspan="2" id="option_col_name"
+                class="center nowrap">
+            </td>
         </tr>
         </thead>
         <tbody id="where">
@@ -581,8 +619,13 @@ for ($i = 0; $i < count($GLOBALS['PMD']["TABLE_NAME"]); $i++) {
             </td>
             </tr>
             <tr>
-            <td width="58" class="nowrap"><?php echo __('Value'); ?>/<br/><?php echo __('subquery'); ?></td>
-                <td width="102"><textarea id="having" value="" cols="18"></textarea></td>
+                <td width="58" class="nowrap">
+                    <?php echo __('Value'); ?>/<br/>
+                    <?php echo __('subquery'); ?>
+                </td>
+                <td width="102">
+                    <textarea id="having" value="" cols="18"></textarea>
+                </td>
             </tr>
         </tbody>
         <tbody>
@@ -621,9 +664,11 @@ for ($i = 0; $i < count($GLOBALS['PMD']["TABLE_NAME"]); $i++) {
     <td class="input_tab">
         <table width="168" class="center" cellpadding="2" cellspacing="0">
         <thead>
-        <tr>
-        <td colspan="2" class="center nowrap"><strong><?php echo __('Rename to'); ?></strong></td>
-        </tr>
+            <tr>
+                <td colspan="2" class="center nowrap">
+                    <strong><?php echo __('Rename to'); ?></strong>
+                </td>
+            </tr>
         </thead>
         <tbody id="rename_to">
         <tr>
@@ -744,11 +789,13 @@ for ($i = 0; $i < count($GLOBALS['PMD']["TABLE_NAME"]); $i++) {
     <td class="frams8"></td>
     <td class="input_tab">
         <table width="168" class="center" cellpadding="2" cellspacing="0">
-        <thead>
-        <tr>
-        <td colspan="2" class="center nowrap"><strong><?php echo __('Aggregate'); ?></strong></td>
-        </tr>
-        </thead>
+            <thead>
+                <tr>
+                    <td colspan="2" class="center nowrap">
+                        <strong><?php echo __('Aggregate'); ?></strong>
+                    </td>
+                </tr>
+            </thead>
         <tbody>
         <tr>
         <td width="58" class="nowrap"><?php echo __('Operator'); ?></td>
@@ -861,10 +908,12 @@ if (! empty($_REQUEST['query'])) {
     echo '<div id="box">';
     echo '<span id="boxtitle"></span>';
     echo '<form method="post" action="db_qbe.php">';
-    echo '<textarea cols="80" name="sql_query" id="textSqlquery" rows="15"></textarea><div id="tblfooter">';
+    echo '<textarea cols="80" name="sql_query" id="textSqlquery"'
+        . ' rows="15"></textarea><div id="tblfooter">';
     echo '  <input type="submit" name="submit_sql" class="btn" />';
-    echo '  <input type="button" name="cancel" value="' . __('Cancel') . '" onclick="closebox()" class="btn" />';
-    echo PMA_generate_common_hidden_inputs($GLOBALS['db']);
+    echo '  <input type="button" name="cancel" value="'
+        . __('Cancel') . '" onclick="closebox()" class="btn" />';
+    echo PMA_URL_getHiddenInputs($_GET['db']);
     echo '</div></p>';
     echo '</form></div>';
 
@@ -872,8 +921,18 @@ if (! empty($_REQUEST['query'])) {
 
 
 <!-- cache images -->
-<img src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/2leftarrow_m.png'); ?>" width="0" height="0" alt="" />
-<img src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/rightarrow1.png'); ?>" width="0" height="0" alt="" />
-<img src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/rightarrow2.png'); ?>" width="0" height="0" alt="" />
-<img src="<?php echo $_SESSION['PMA_Theme']->getImgPath('pmd/uparrow2_m.png'); ?>" width="0" height="0" alt="" />
-<div id="PMA_disable_floating_menubar"></div>
+<?php
+echo '<img src="'
+    . $_SESSION['PMA_Theme']->getImgPath('pmd/2leftarrow_m.png')
+    . '" width="0" height="0" alt="" />'
+    . '<img src="'
+    . $_SESSION['PMA_Theme']->getImgPath('pmd/rightarrow1.png')
+    . '" width="0" height="0" alt="" />'
+    . '<img src="'
+    . $_SESSION['PMA_Theme']->getImgPath('pmd/rightarrow2.png')
+    . '" width="0" height="0" alt="" />'
+    . '<img src="'
+    . $_SESSION['PMA_Theme']->getImgPath('pmd/uparrow2_m.png')
+    . '" width="0" height="0" alt="" />'
+    . '<div id="PMA_disable_floating_menubar"></div>';
+?>
