@@ -1,6 +1,7 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
+ * Server import page
  *
  * @package PhpMyAdmin
  */
@@ -21,7 +22,6 @@ $scripts->addFile('import.js');
 require 'libraries/server_common.inc.php';
 
 $import_type = 'server';
-require 'libraries/display_import.lib.php';
+require 'libraries/display_import.inc.php';
 
 ?>
-
