@@ -66,13 +66,18 @@ h3 {
 
 a, a:link,
 a:visited,
-a:active {
+a:active,
+button.mult_submit,
+.checkall_box+label {
     text-decoration:    none;
     color:              #0000FF;
     cursor:             pointer;
 }
 
-a:hover {
+a:hover,
+button.mult_submit:hover,
+button.mult_submit:focus,
+.checkall_box+label:hover {
     text-decoration:    underline;
     color:              #FF0000;
 }
@@ -238,6 +243,23 @@ fieldset .formelement {
     white-space:        nowrap;
 }
 
+@media all and (min-width: 1600px) {
+    fieldset .formelement {
+        clear: none;
+    }
+    #relationalTable td:first-child + td {
+        width: 25%;
+    }
+    #relationalTable td:first-child + td select {
+        width: 32%;
+        margin-right: 1%;
+    }
+    #relationalTable {
+        width: 100%;
+    }
+
+}
+
 /* revert for Gecko */
 fieldset div[class=formelement] {
     white-space:        normal;
@@ -368,77 +390,17 @@ img.lightbulb {
     border:             1px dashed #000000;
 }
 
-/* MySQL Parser */
-.syntax {
-    font-size:          80%;
-}
-
-.syntax a {
+/* Doc links in SQL */
+.cm-sql-doc {
     text-decoration: none;
-    border-bottom:1px dotted black;
-}
-
-.syntax_comment {
-    padding-left:       4pt;
-    padding-right:      4pt;
-}
-
-.syntax_digit {
-}
-
-.syntax_digit_hex {
-}
-
-.syntax_digit_integer {
-}
-
-.syntax_digit_float {
-}
-
-.syntax_punct {
-}
-
-.syntax_alpha {
-}
-
-.syntax_alpha_columnType {
-    text-transform:     uppercase;
-}
-
-.syntax_alpha_columnAttrib {
-    text-transform:     uppercase;
-}
-
-.syntax_alpha_reservedWord {
-    text-transform:     uppercase;
-    font-weight:        bold;
-}
-
-.syntax_alpha_functionName {
-    text-transform:     uppercase;
-}
-
-.syntax_alpha_identifier {
-}
-
-.syntax_alpha_charset {
-}
-
-.syntax_alpha_variable {
-}
-
-.syntax_quote {
-    white-space:        pre;
-}
-
-.syntax_quote_backtick {
+    border-bottom: 1px dotted #000;
+    color: inherit !important;
 }
 
 /* leave some space between icons and text */
 .icon {
     vertical-align:     middle;
-    margin-right:       0.3em;
-    margin-left:        0.3em;
+    margin-<?php echo $left; ?>:        0.3em;
 }
 
 /* no extra space in table cells */
@@ -452,7 +414,7 @@ td .icon {
 }
 
 /* message boxes: error, confirmation */
-#pma_errors {
+#pma_errors, #pma_demo {
     padding: 0 0.5em;
 }
 
@@ -818,7 +780,7 @@ div#tablestatistics table {
     margin-<?php echo $right; ?>: 0.5em;
     min-width: 16em;
 }
-/* END table stats */
+/* end table stats */
 
 
 /* server privileges */
@@ -827,7 +789,7 @@ div#tablestatistics table {
 #tabledatabases td {
     vertical-align: middle;
 }
-/* END server privileges */
+/* end server privileges */
 
 
 
@@ -848,7 +810,6 @@ div#tablestatistics table {
 
 #serverinfo .item {
     white-space:        nowrap;
-    float: <?php echo $left; ?>
 }
 
 #goto_pagetop {
@@ -861,9 +822,12 @@ div#tablestatistics table {
 }
 
 #span_table_comment {
-    font-weight:        normal;
-    font-style:         italic;
-    white-space:        nowrap;
+    font-weight: bold;
+    font-style: italic;
+    white-space: nowrap;
+    margin-left: 10px;
+    color: #D6D6D6;
+    text-shadow: none;
 }
 
 #serverinfo img {
@@ -953,7 +917,15 @@ div#tablestatistics table {
 #fieldset_user_global_rights fieldset {
     float: <?php echo $left; ?>;
 }
-/* END user privileges */
+
+#fieldset_user_group_rights fieldset {
+    float: <?php echo $left; ?>;
+}
+
+#fieldset_user_global_rights legend input {
+    margin-<?php echo $left; ?>: 2em;
+}
+/* end user privileges */
 
 
 /* serverstatus */
@@ -1051,8 +1023,15 @@ div#chartVariableSettings {
     margin-left:10px;
 }
 
+table#chartGrid td {
+    padding: 3px;
+    margin: 0;
+}
+
 table#chartGrid div.monitorChart {
     background: #EBEBEB;
+    overflow: hidden;
+    border: none;
 }
 
 div#serverstatus div.tabLinks {
@@ -1174,17 +1153,45 @@ div#querywindowcontainer {
 div#querywindowcontainer fieldset {
     margin-top: 0;
 }
-/* END querywindow */
+/* end querywindow */
 
 /* profiling */
 
 div#profilingchart {
-    width: 550px;
+    width: 850px;
     height: 370px;
     float: left;
 }
 
-/* END profiling */
+#profilingchart .jqplot-highlighter-tooltip{
+    top: auto !important;
+    left: 11px;
+    bottom:24px;
+}
+
+#profilesummarytable th.header, #profiletable th.header{
+    cursor: pointer;
+}
+
+#profilesummarytable th.header .sorticon, #profiletable th.header .sorticon{
+    width: 16px;
+    height: 16px;
+    background-repeat: no-repeat;
+    background-position: right center;
+    display: inline-block;
+    vertical-align: middle;
+    float: right;
+}
+
+#profilesummarytable th.headerSortUp .sorticon, #profiletable th.headerSortUp .sorticon{
+    background-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath('s_desc.png');?>);
+}
+
+#profilesummarytable th.headerSortDown .sorticon, #profiletable th.headerSortDown .sorticon{
+    background-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath('s_asc.png');?>);
+}
+
+/* end profiling */
 
 /* querybox */
 
@@ -1240,16 +1247,27 @@ div#queryboxcontainer div#bookmarkoptions {
 #maincontainer li {
     margin:  0.2em 0em;
 }
-/* END main page */
+
+#full_name_layer {
+    position: absolute;
+    padding: 2px;
+    margin-top: -3px;
+    z-index: 801;
+
+    border: solid 1px #888;
+    background: #fff;
+
+}
+/* end main page */
 
 /* iconic view for ul items */
 
 li.no_bullets {
-    list-style-type:none !important;    
+    list-style-type:none !important;
     margin-left: -25px !important;      //align with other list items which have bullets
 }
 
-/* END iconic view for ul items */
+/* end iconic view for ul items */
 
 #body_browse_foreigners {
     background:         <?php echo $GLOBALS['cfg']['NaviBackground']; ?>;
@@ -1298,11 +1316,35 @@ li.no_bullets {
     float: <?php echo $left; ?>;
 }
 
+#div_mysql_charset_collations table th,
+#div_mysql_charset_collations table td {
+    padding: 0.4em;
+}
+
+#div_mysql_charset_collations table th#collationHeader {
+    width: 35%;
+}
+
 .operations_half_width {
     width: 48%;
     float: <?php echo $left; ?>;
 }
-
+.operations_half_width input[type=text],
+.operations_half_width input[type=password],
+.operations_half_width input[type=number],
+.operations_half_width select {
+    width: 95%;
+}
+.operations_half_width input[type=text].halfWidth,
+.operations_half_width input[type=password].halfWidth,
+.operations_half_width input[type=number].halfWidth,
+.operations_half_width select.halfWidth {
+    width: 40%;
+}
+.operations_half_width ul {
+    list-style-type: none;
+    padding: 0;
+}
 .operations_full_width {
     width: 100%;
     clear: both;
@@ -1331,22 +1373,34 @@ div.sqlvalidate {
     padding:            0.3em;
     margin-top:         0;
     margin-bottom:      0;
+    max-height:         10em;
+    overflow:           auto;
+}
+
+#result_query div.sqlOuter,
+div.sqlvalidate  {
     border:             <?php echo $GLOBALS['cfg']['MainColor']; ?> solid 1px;
     border-top:         0;
     border-bottom:      0;
-    max-height:         10em;
-    overflow:           auto;
+    background:         <?php echo $GLOBALS['cfg']['BgOne']; ?>;
+}
+
+#PMA_slidingMessage code.sql {
+    border:             <?php echo $GLOBALS['cfg']['MainColor']; ?> solid 1px;
+    border-top:         0;
     background:         <?php echo $GLOBALS['cfg']['BgOne']; ?>;
 }
 
 #main_pane_left {
     width:              60%;
+    min-width:          260px;
     float:              <?php echo $left; ?>;
     padding-top:        1em;
 }
 
 #main_pane_right {
-    margin-<?php echo $left; ?>: 60%;
+    overflow:           hidden;
+    min-width:          160px;
     padding-top: 1em;
     padding-<?php echo $left; ?>: 1em;
 }
@@ -1379,7 +1433,8 @@ textarea#partitiondefinition {
 }
 
 #list_server {
-    list-style-image: none;
+    list-style-type: none;
+    padding: 0;
 }
 
 /**
@@ -1440,6 +1495,9 @@ table#serverconnection_trg_local  {
   *  Validation error message styles
   */
 input[type=text].invalid_value,
+input[type=password].invalid_value,
+input[type=number].invalid_value,
+input[type=date].invalid_value,
 .invalid_value {
     background: #FFCCCC;
 }
@@ -1543,7 +1601,6 @@ select#table_select {
     margin-bottom: 0;
 }
 
-#quick_or_custom,
 #output_quick_export {
     display: none;
 }
@@ -1600,7 +1657,16 @@ input#input_import_file {
     padding: 0.3em;
     margin: 0.1em;
 }
-
+#structure-action-links a {
+    margin-<?php echo $right; ?>: 1em;
+}
+#addColumns input[type="radio"] {
+    margin: 0;
+    margin-<?php echo $left; ?>: 1em;
+}
+#addColumns input[type="submit"] {
+    margin-<?php echo $left; ?>: 1em;
+}
 .margin#change_column_dialog {
     margin: 0 .5em;
 }
@@ -1811,7 +1877,7 @@ fieldset .disabled-field td {
 }
 
 .config-form .lastrow {
-    background: <?php echo $GLOBALS['cfg']['ThBackground']; ?>;;
+    background: <?php echo $GLOBALS['cfg']['ThBackground']; ?>;
     padding: .5em;
     text-align: center;
 }
@@ -1842,6 +1908,8 @@ fieldset .disabled-field td {
 }
 
 .config-form input[type="text"],
+.config-form input[type="password"],
+.config-form input[type="number"],
 .config-form select,
 .config-form textarea {
     border: 1px #A7A6AA solid;
@@ -1849,6 +1917,8 @@ fieldset .disabled-field td {
 }
 
 .config-form input[type="text"]:focus,
+.config-form input[type="password"]:focus,
+.config-form input[type="number"]:focus,
 .config-form select:focus,
 .config-form textarea:focus {
     border:     1px #6676FF solid;
@@ -1952,6 +2022,9 @@ fieldset .disabled-field td {
 }
 
 #table_columns input[type="text"],
+#table_columns input[type="password"],
+#table_columns input[type="number"],
+#table_columns input[type="date"],
 #table_columns select {
     width:              10em;
     box-sizing:         border-box;
@@ -2188,7 +2261,9 @@ fieldset .disabled-field td {
     position: absolute;
 }
 
-.cEdit input[type=text] {
+.cEdit input[type=text],
+.cEdit input[type=password],
+.cEdit input[type=number] {
     background: #FFF;
     height: 100%;
     margin: 0;
@@ -2228,6 +2303,11 @@ fieldset .disabled-field td {
     height: 10em;
 }
 
+.cEdit .edit_area_right {
+    position: absolute;
+    right: 0;
+}
+
 .cEdit .goto_link {
     background: #EEE;
     color: #555;
@@ -2243,7 +2323,7 @@ fieldset .disabled-field td {
 .ui-timepicker-div .ui-widget-header { margin-bottom: 8px; }
 .ui-timepicker-div dl { text-align: left; }
 .ui-timepicker-div dl dt { height: 25px; }
-.ui-timepicker-div dl dd { margin: -25px 0 10px 65px; }
+.ui-timepicker-div dl dd { margin: -25px 0 10px 85px; }
 .ui-timepicker-div td { font-size: 90%; }
 
 input.btn {
@@ -2261,7 +2341,8 @@ body .ui-widget {
 
 /* jqPlot */
 
-/*rules for the plot target div.  These will be cascaded down to all plot elements according to css rules*/
+/*rules for the plot target div.  These will be cascaded down to all plot elements
+according to css rules*/
 .jqplot-target {
     position: relative;
     color: #222222;
@@ -2288,13 +2369,17 @@ body .ui-widget {
     margin-right: 10px;
 }
 
-.jqplot-y2axis, .jqplot-y3axis, .jqplot-y4axis, .jqplot-y5axis, .jqplot-y6axis, .jqplot-y7axis, .jqplot-y8axis, .jqplot-y9axis, .jqplot-yMidAxis {
+.jqplot-y2axis, .jqplot-y3axis, .jqplot-y4axis, .jqplot-y5axis, .jqplot-y6axis,
+.jqplot-y7axis, .jqplot-y8axis, .jqplot-y9axis, .jqplot-yMidAxis {
     margin-left: 10px;
     margin-right: 10px;
 }
 
 /*rules applied to all axis tick divs*/
-.jqplot-axis-tick, .jqplot-xaxis-tick, .jqplot-yaxis-tick, .jqplot-x2axis-tick, .jqplot-y2axis-tick, .jqplot-y3axis-tick, .jqplot-y4axis-tick, .jqplot-y5axis-tick, .jqplot-y6axis-tick, .jqplot-y7axis-tick, .jqplot-y8axis-tick, .jqplot-y9axis-tick, .jqplot-yMidAxis-tick {
+.jqplot-axis-tick, .jqplot-xaxis-tick, .jqplot-yaxis-tick, .jqplot-x2axis-tick,
+.jqplot-y2axis-tick, .jqplot-y3axis-tick, .jqplot-y4axis-tick, .jqplot-y5axis-tick,
+.jqplot-y6axis-tick, .jqplot-y7axis-tick, .jqplot-y8axis-tick, .jqplot-y9axis-tick,
+.jqplot-yMidAxis-tick {
     position: absolute;
     white-space: pre;
 }
@@ -2333,7 +2418,8 @@ body .ui-widget {
     font-size: 1.5em;
 }
 
-.jqplot-y2axis-tick, .jqplot-y3axis-tick, .jqplot-y4axis-tick, .jqplot-y5axis-tick, .jqplot-y6axis-tick, .jqplot-y7axis-tick, .jqplot-y8axis-tick, .jqplot-y9axis-tick {
+.jqplot-y2axis-tick, .jqplot-y3axis-tick, .jqplot-y4axis-tick, .jqplot-y5axis-tick,
+.jqplot-y6axis-tick, .jqplot-y7axis-tick, .jqplot-y8axis-tick, .jqplot-y9axis-tick {
     left: 0px;
     /* initial position untill tick is drawn in proper place */
     top: 15px;
@@ -2371,7 +2457,9 @@ body .ui-widget {
     position: absolute;
 }
 
-.jqplot-y2axis-label, .jqplot-y3axis-label, .jqplot-y4axis-label, .jqplot-y5axis-label, .jqplot-y6axis-label, .jqplot-y7axis-label, .jqplot-y8axis-label, .jqplot-y9axis-label {
+.jqplot-y2axis-label, .jqplot-y3axis-label, .jqplot-y4axis-label,
+.jqplot-y5axis-label, .jqplot-y6axis-label, .jqplot-y7axis-label,
+.jqplot-y8axis-label, .jqplot-y9axis-label {
 /*    text-align: center;*/
     font-size: 11pt;
     margin-left: 10px;
@@ -2520,3 +2608,34 @@ div.jqplot-noData-container {
     text-align: center;
     background-color: rgba(96%, 96%, 96%, 0.3);
 }
+
+#relationalTable select {
+    width: 125px;
+    margin-right: 5px;
+}
+
+.report-data {
+    height:13em;
+    overflow:scroll;
+    width:570px;
+    border: solid 1px;
+    background: white;
+    padding: 2px;
+}
+
+.report-description {
+    height:10em;
+    width:570px;
+}
+
+div#page_content div#tableslistcontainer table.data {
+    border-top: 0.1px solid #EEEEEE;
+}
+
+div#page_content form#db_search_form.ajax fieldset {
+    margin-top: -0.3em;
+}
+
+div#page_content div#tableslistcontainer, div#page_content div.notice, div#page_content div#result_query {
+    margin-top: 1em;
+}
